@@ -1,4 +1,4 @@
-/* $Id: exo-die-editor.c 22884 2006-08-26 12:40:43Z benny $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2006 Benedikt Meurer <benny@xfce.org>.
  *
@@ -45,8 +45,6 @@ enum
 
 
 
-static void     exo_die_editor_class_init     (ExoDieEditorClass  *klass);
-static void     exo_die_editor_init           (ExoDieEditor       *editor);
 static void     exo_die_editor_finalize       (GObject            *object);
 static void     exo_die_editor_get_property   (GObject            *object,
                                                guint               prop_id,
@@ -80,7 +78,6 @@ struct _ExoDieEditor
   GtkTable         __parent__;
   GtkWidget       *name_entry;
   GtkWidget       *icon_button;
-  GtkTooltips     *tooltips;
   ExoDieEditorMode mode;
   gchar           *name;
   gchar           *comment;
@@ -93,36 +90,7 @@ struct _ExoDieEditor
 
 
 
-static GObjectClass *exo_die_editor_parent_class;
-
-
-
-GType
-exo_die_editor_get_type (void)
-{
-  static GType type = G_TYPE_INVALID;
-
-  if (G_UNLIKELY (type == G_TYPE_INVALID))
-    {
-      static const GTypeInfo info =
-      {
-        sizeof (ExoDieEditorClass),
-        NULL,
-        NULL,
-        (GClassInitFunc) exo_die_editor_class_init,
-        NULL,
-        NULL,
-        sizeof (ExoDieEditor),
-        0,
-        (GInstanceInitFunc) exo_die_editor_init,
-        NULL,
-      };
-
-      type = g_type_register_static (GTK_TYPE_TABLE, I_("ExoDieEditor"), &info, 0);
-    }
-
-  return type;
-}
+G_DEFINE_TYPE (ExoDieEditor, exo_die_editor, GTK_TYPE_TABLE)
 
 
 
@@ -131,9 +99,6 @@ exo_die_editor_class_init (ExoDieEditorClass *klass)
 {
   GObjectClass *gobject_class;
 
-  /* determine the parent type class */
-  exo_die_editor_parent_class = g_type_class_peek_parent (klass);
-
   gobject_class = G_OBJECT_CLASS (klass);
   gobject_class->finalize = exo_die_editor_finalize;
   gobject_class->get_property = exo_die_editor_get_property;
@@ -292,7 +257,6 @@ exo_die_editor_init (ExoDieEditor *editor)
   GtkWidget *align;
   GtkWidget *entry;
   GtkWidget *label;
-  gchar     *text;
   gint       row;
 
   /* start with sane defaults */
@@ -303,10 +267,6 @@ exo_die_editor_init (ExoDieEditor *editor)
   editor->name = g_strdup ("");
   editor->url = g_strdup ("");
 
-  /* allocate the shared tooltips */
-  editor->tooltips = gtk_tooltips_new ();
-  exo_gtk_object_ref_sink (GTK_OBJECT (editor->tooltips));
-
   /* configure the table */
   gtk_table_resize (GTK_TABLE (editor), 8, 2);
   gtk_table_set_col_spacings (GTK_TABLE (editor), 12);
@@ -315,13 +275,11 @@ exo_die_editor_init (ExoDieEditor *editor)
   row = 0;
 
   /* TRANSLATORS: Label in "Create Launcher"/"Create Link" dialog, make sure to avoid mnemonic conflicts */
-  text = g_strdup_printf ("<b>%s</b>", _("_Name:"));
-  label = gtk_label_new_with_mnemonic (text);
+  label = gtk_label_new_with_mnemonic (_("_Name:"));
   gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
   gtk_misc_set_alignment (GTK_MISC (label), 1.0f, 0.5f);
   gtk_table_attach (GTK_TABLE (editor), label, 0, 1, row, row + 1, GTK_FILL, GTK_FILL, 0, 3);
   gtk_widget_show (label);
-  g_free (text);
 
   editor->name_entry = gtk_entry_new ();
   gtk_entry_set_activates_default (GTK_ENTRY (editor->name_entry), TRUE);
@@ -333,13 +291,11 @@ exo_die_editor_init (ExoDieEditor *editor)
   row += 1;
 
   /* TRANSLATORS: Label in "Create Launcher"/"Create Link" dialog, make sure to avoid mnemonic conflicts */
-  text = g_strdup_printf ("<b>%s</b>", _("C_omment:"));
-  label = gtk_label_new_with_mnemonic (text);
+  label = gtk_label_new_with_mnemonic (_("C_omment:"));
   gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
   gtk_misc_set_alignment (GTK_MISC (label), 1.0f, 0.5f);
   gtk_table_attach (GTK_TABLE (editor), label, 0, 1, row, row + 1, GTK_FILL, GTK_FILL, 0, 3);
   gtk_widget_show (label);
-  g_free (text);
 
   entry = gtk_entry_new ();
   gtk_entry_set_activates_default (GTK_ENTRY (entry), TRUE);
@@ -351,13 +307,11 @@ exo_die_editor_init (ExoDieEditor *editor)
   row += 1;
 
   /* TRANSLATORS: Label in "Create Launcher" dialog, make sure to avoid mnemonic conflicts */
-  text = g_strdup_printf ("<b>%s</b>", _("Comm_and:"));
-  label = gtk_label_new_with_mnemonic (text);
+  label = gtk_label_new_with_mnemonic (_("Comm_and:"));
   gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
   gtk_misc_set_alignment (GTK_MISC (label), 1.0f, 0.5f);
   exo_binding_new_full (G_OBJECT (editor), "mode", G_OBJECT (label), "visible", exo_die_true_if_application, NULL, NULL);
   gtk_table_attach (GTK_TABLE (editor), label, 0, 1, row, row + 1, GTK_FILL, GTK_FILL, 0, 3);
-  g_free (text);
 
   entry = exo_die_command_entry_new ();
   exo_mutual_binding_new (G_OBJECT (editor), "command", G_OBJECT (entry), "text");
@@ -368,13 +322,11 @@ exo_die_editor_init (ExoDieEditor *editor)
   row += 1;
 
   /* TRANSLATORS: Label in "Create Link" dialog, make sure to avoid mnemonic conflicts */
-  text = g_strdup_printf ("<b>%s</b>", _("_URL:"));
-  label = gtk_label_new_with_mnemonic (text);
+  label = gtk_label_new_with_mnemonic (_("_URL:"));
   gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
   gtk_misc_set_alignment (GTK_MISC (label), 1.0f, 0.5f);
   exo_binding_new_full (G_OBJECT (editor), "mode", G_OBJECT (label), "visible", exo_die_true_if_link, NULL, NULL);
   gtk_table_attach (GTK_TABLE (editor), label, 0, 1, row, row + 1, GTK_FILL, GTK_FILL, 0, 3);
-  g_free (text);
 
   entry = gtk_entry_new ();
   gtk_entry_set_activates_default (GTK_ENTRY (entry), TRUE);
@@ -386,13 +338,11 @@ exo_die_editor_init (ExoDieEditor *editor)
   row += 1;
 
   /* TRANSLATORS: Label in "Create Launcher"/"Create Link" dialog, make sure to avoid mnemonic conflicts */
-  text = g_strdup_printf ("<b>%s</b>", _("_Icon:"));
-  label = gtk_label_new_with_mnemonic (text);
+  label = gtk_label_new_with_mnemonic (_("_Icon:"));
   gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
   gtk_misc_set_alignment (GTK_MISC (label), 1.0f, 0.5f);
   gtk_table_attach (GTK_TABLE (editor), label, 0, 1, row, row + 1, GTK_FILL, GTK_FILL, 0, 3);
   gtk_widget_show (label);
-  g_free (text);
 
   align = gtk_alignment_new (0.0f, 0.5f, 0.0f, 0.0f);
   gtk_table_attach (GTK_TABLE (editor), align, 1, 2, row, row + 1, GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 3);
@@ -408,29 +358,22 @@ exo_die_editor_init (ExoDieEditor *editor)
   label = gtk_label_new (_("No icon"));
   gtk_container_add (GTK_CONTAINER (editor->icon_button), label);
   gtk_widget_show (label);
-  
-  row += 1;
-
-  /* add an empty row to get some spacing before the options */
-  gtk_table_set_row_spacing (GTK_TABLE (editor), row, 18);
 
   row += 1;
 
-  text = g_strdup_printf ("<b>%s</b>", _("Options:"));
-  label = gtk_label_new_with_mnemonic (text);
+  label = gtk_label_new (_("Options:"));
   gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
   gtk_misc_set_alignment (GTK_MISC (label), 1.0f, 0.5f);
   exo_binding_new_full (G_OBJECT (editor), "mode", G_OBJECT (label), "visible", exo_die_true_if_application, NULL, NULL);
   gtk_table_attach (GTK_TABLE (editor), label, 0, 1, row, row + 1, GTK_FILL, GTK_FILL, 0, 3);
-  g_free (text);
 
   /* TRANSLATORS: Check button label in "Create Launcher" dialog, make sure to avoid mnemonic conflicts
    *              and sync your translations with the translations in Thunar and xfce4-panel.
    */
   button = gtk_check_button_new_with_mnemonic (_("Use _startup notification"));
-  gtk_tooltips_set_tip (editor->tooltips, button, _("Select this option to enable startup notification when the command "
-                                                    "is run from the file manager or the menu. Not every application supports "
-                                                    "startup notification."), NULL);
+  gtk_widget_set_tooltip_text (button, _("Select this option to enable startup notification when the command "
+                                         "is run from the file manager or the menu. Not every application supports "
+                                         "startup notification."));
   exo_mutual_binding_new (G_OBJECT (editor), "snotify", G_OBJECT (button), "active");
   exo_binding_new_full (G_OBJECT (editor), "mode", G_OBJECT (button), "visible", exo_die_true_if_application, NULL, NULL);
   gtk_table_attach (GTK_TABLE (editor), button, 1, 2, row, row + 1, GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 3);
@@ -441,7 +384,7 @@ exo_die_editor_init (ExoDieEditor *editor)
    *              and sync your translations with the translations in Thunar and xfce4-panel.
    */
   button = gtk_check_button_new_with_mnemonic (_("Run in _terminal"));
-  gtk_tooltips_set_tip (editor->tooltips, button, _("Select this option to run the command in a terminal window."), NULL);
+  gtk_widget_set_tooltip_text (button, _("Select this option to run the command in a terminal window."));
   exo_mutual_binding_new (G_OBJECT (editor), "terminal", G_OBJECT (button), "active");
   exo_binding_new_full (G_OBJECT (editor), "mode", G_OBJECT (button), "visible", exo_die_true_if_application, NULL, NULL);
   gtk_table_attach (GTK_TABLE (editor), button, 1, 2, row, row + 1, GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 3);
@@ -455,7 +398,6 @@ exo_die_editor_finalize (GObject *object)
   ExoDieEditor *editor = EXO_DIE_EDITOR (object);
 
   /* cleanup */
-  g_object_unref (G_OBJECT (editor->tooltips));
   g_free (editor->command);
   g_free (editor->comment);
   g_free (editor->icon);
@@ -600,7 +542,7 @@ exo_die_editor_icon_clicked (GtkWidget    *button,
                                            -1);
 
   /* check if we have an icon to set for the chooser */
-  if (G_LIKELY (editor->icon != NULL && *editor->icon != '\0'))
+  if (G_LIKELY (!exo_str_is_empty (editor->icon)))
     exo_icon_chooser_dialog_set_icon (EXO_ICON_CHOOSER_DIALOG (chooser), editor->icon);
 
   /* run the chooser dialog */
@@ -689,7 +631,7 @@ exo_die_editor_cell_data_func (GtkCellLayout   *cell_layout,
       /* try to load the icon from the file */
       pixbuf = gdk_pixbuf_new_from_file (icon, NULL);
     }
-  else if (icon != NULL && *icon != '\0')
+  else if (!exo_str_is_empty (icon))
     {
       /* determine the appropriate icon theme */
       icon_theme = gtk_icon_theme_get_for_screen (gtk_widget_get_screen (GTK_WIDGET (editor)));
@@ -757,10 +699,12 @@ exo_die_editor_get_complete (ExoDieEditor *editor)
   switch (editor->mode)
     {
     case EXO_DIE_EDITOR_MODE_APPLICATION:
-      return (*editor->name != '\0' && *editor->command != '\0');
+      return (!exo_str_is_empty (editor->name)
+              && !exo_str_is_empty (editor->command));
 
     case EXO_DIE_EDITOR_MODE_LINK:
-      return (*editor->name != '\0' && *editor->url != '\0');
+      return (!exo_str_is_empty (editor->name)
+              && !exo_str_is_empty (editor->url));
 
     default:
       g_assert_not_reached ();
@@ -1098,7 +1042,7 @@ exo_die_editor_set_icon (ExoDieEditor *editor,
           /* try to load the icon from the file */
           pixbuf = gdk_pixbuf_new_from_file (icon, NULL);
         }
-      else if (icon != NULL && *icon != '\0')
+      else if (!exo_str_is_empty (icon))
         {
           /* determine the appropriate icon theme */
           icon_theme = gtk_icon_theme_get_for_screen (gtk_widget_get_screen (GTK_WIDGET (editor)));
