@@ -1,4 +1,4 @@
-/* $Id: main.c 24275 2007-01-06 18:09:04Z benny $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2006 Benedikt Meurer <benny@xfce.org>.
  *
@@ -25,7 +25,9 @@
 #ifdef HAVE_MEMORY_H
 #include <memory.h>
 #endif
+#ifdef HAVE_STDIO_H
 #include <stdio.h>
+#endif
 #ifdef HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
@@ -33,8 +35,7 @@
 #include <string.h>
 #endif
 
-#include <glib/gstdio.h>
-
+#include <gio/gio.h>
 #include <exo-desktop-item-edit/exo-die-editor.h>
 #include <exo-desktop-item-edit/exo-die-utils.h>
 
@@ -44,6 +45,9 @@
 #include <gdk/gdkx.h>
 #endif
 
+/* string with fallback spoort */
+#define STR_FB(string,fallback) ((string != NULL && *string != '\0') ? string : fallback)
+
 
 
 /* --- constants --- */
@@ -56,12 +60,12 @@ static const gchar *ICON_NAMES[] = { "applications-other", "applications-interne
 /* --- globals --- */
 static gboolean opt_create_new = FALSE;
 static gboolean opt_version = FALSE;
-static gchar   *opt_type = "Application";
-static gchar   *opt_name = "";
-static gchar   *opt_comment = "";
-static gchar   *opt_command = "";
-static gchar   *opt_url = "";
-static gchar   *opt_icon = "";
+static gchar   *opt_type = NULL;
+static gchar   *opt_name = NULL;
+static gchar   *opt_comment = NULL;
+static gchar   *opt_command = NULL;
+static gchar   *opt_url = NULL;
+static gchar   *opt_icon = NULL;
 static gint     opt_xid = 0;
 
 
@@ -76,7 +80,7 @@ static GOptionEntry option_entries[] =
   { "command", 0, 0, G_OPTION_ARG_STRING, &opt_command, N_ ("Preset command when creating a launcher"), NULL, },
   { "url", 0, 0, G_OPTION_ARG_STRING, &opt_url, N_ ("Preset URL when creating a link"), NULL, },
   { "icon", 0, 0, G_OPTION_ARG_STRING, &opt_icon, N_ ("Preset icon when creating a desktop file"), NULL, },
-  { "version", 'v', 0, G_OPTION_ARG_NONE, &opt_version, N_ ("Print version information and exit"), NULL, },
+  { "version", 'V', 0, G_OPTION_ARG_NONE, &opt_version, N_ ("Print version information and exit"), NULL, },
   { "xid", 0, G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_INT, &opt_xid, NULL, NULL, },
   { NULL, },
 };
@@ -99,13 +103,16 @@ main (int argc, char **argv)
   GtkWidget       *editor;
   GKeyFile        *key_file;
   GError          *error = NULL;
-  gchar           *filename;
-  gchar           *basename;
-  gchar           *dirname;
+  gchar           *base_name;
   gchar           *value;
   gchar           *s;
   gint             response;
   gint             result = EXIT_SUCCESS;
+  GFile           *gfile, *gfile_parent;
+  gchar           *contents;
+  gsize            length = 0;
+  gboolean         res;
+  GFileType        file_type;
 
   /* setup translation domain */
   xfce_textdomain (GETTEXT_PACKAGE, PACKAGE_LOCALE_DIR, "UTF-8");
@@ -128,20 +135,16 @@ main (int argc, char **argv)
       if (G_UNLIKELY (error != NULL))
         {
           /* use the supplied error message */
-          s = g_strdup (error->message);
+          g_critical ("%s", error->message);
           g_error_free (error);
         }
       else
         {
           /* no error message, the GUI initialization failed */
-          const gchar *display_name = gdk_get_display_arg_name ();
-          s = g_strdup_printf ("%s: %s", _("Failed to open display"), (display_name != NULL) ? display_name : " ");
+          g_critical ("%s %s", _("Failed to open display"),
+                      STR_FB (gdk_get_display_arg_name (), ""));
         }
 
-      /* tell the user about it */
-      g_fprintf (stderr, "%s: %s\n", g_get_prgname (), s);
-      g_free (s);
-
       /* and fail */
       return EXIT_FAILURE;
     }
@@ -165,55 +168,83 @@ main (int argc, char **argv)
   /* verify that a file/folder is specified */
   if (G_UNLIKELY (argc != 2))
     {
-      g_fprintf (stderr, "%s: %s\n", g_get_prgname (), _("No file/folder specified"));
+      g_critical (_("No file/folder specified"));
       return EXIT_FAILURE;
     }
 
   /* allocate a key file */
   key_file = g_key_file_new ();
+  gfile = g_file_new_for_commandline_arg (argv[1]);
 
   /* create new key file if --create-new was specified */
   if (G_LIKELY (opt_create_new))
     {
       /* generic stuff */
-      g_key_file_set_value (key_file, "Desktop Entry", "Version", "1.0");
-      g_key_file_set_value (key_file, "Desktop Entry", "Encoding", "UTF-8");
-      g_key_file_set_value (key_file, "Desktop Entry", "Type", opt_type);
-      g_key_file_set_value (key_file, "Desktop Entry", "Name", opt_name);
-      g_key_file_set_value (key_file, "Desktop Entry", "Comment", opt_comment);
+      g_key_file_set_value (key_file, G_KEY_FILE_DESKTOP_GROUP,
+                            G_KEY_FILE_DESKTOP_KEY_VERSION, "1.0");
+      g_key_file_set_value (key_file, G_KEY_FILE_DESKTOP_GROUP,
+                            G_KEY_FILE_DESKTOP_KEY_TYPE, STR_FB (opt_type, "Application"));
+      g_key_file_set_value (key_file, G_KEY_FILE_DESKTOP_GROUP,
+                            G_KEY_FILE_DESKTOP_KEY_NAME, STR_FB (opt_name, ""));
+      g_key_file_set_value (key_file, G_KEY_FILE_DESKTOP_GROUP,
+                            G_KEY_FILE_DESKTOP_KEY_COMMENT, STR_FB (opt_comment, ""));
 
       /* type specific stuff */
-      if (exo_str_is_equal (opt_type, "Link"))
+      if (exo_str_is_equal (opt_type, G_KEY_FILE_DESKTOP_TYPE_LINK))
         {
-          g_key_file_set_value (key_file, "Desktop Entry", "Icon", (*opt_icon != '\0') ? opt_icon : "gnome-fs-bookmark");
-          g_key_file_set_value (key_file, "Desktop Entry", "URL", opt_url);
+          g_key_file_set_value (key_file, G_KEY_FILE_DESKTOP_GROUP,
+                                G_KEY_FILE_DESKTOP_KEY_ICON, STR_FB (opt_icon, "gnome-fs-bookmark"));
+          g_key_file_set_value (key_file, G_KEY_FILE_DESKTOP_GROUP,
+                                G_KEY_FILE_DESKTOP_KEY_URL, STR_FB (opt_url, ""));
         }
       else
         {
-          g_key_file_set_value (key_file, "Desktop Entry", "Categories", "Application;");
-          g_key_file_set_value (key_file, "Desktop Entry", "Exec", opt_command);
-          g_key_file_set_value (key_file, "Desktop Entry", "Icon", opt_icon);
+          g_key_file_set_value (key_file, G_KEY_FILE_DESKTOP_GROUP,
+                                G_KEY_FILE_DESKTOP_KEY_EXEC, STR_FB (opt_command, ""));
+          g_key_file_set_value (key_file, G_KEY_FILE_DESKTOP_GROUP,
+                                G_KEY_FILE_DESKTOP_KEY_ICON, STR_FB (opt_icon, ""));
         }
     }
   else
     {
-      /* try to parse the specified desktop file */
-      if (!g_key_file_load_from_file (key_file, argv[1], G_KEY_FILE_KEEP_COMMENTS | G_KEY_FILE_KEEP_TRANSLATIONS, &error))
+      /* try to load the entire file into memory */
+      res = g_file_load_contents (gfile, NULL, &contents, &length, NULL, &error);
+      if (G_UNLIKELY (!res || length == 0))
         {
           /* we cannot open the file */
-          g_fprintf (stderr, "%s: %s: %s\n", g_get_prgname (), argv[1], error->message);
+          if (G_LIKELY (error != NULL))
+            {
+              g_critical (_("Failed to load contents from \"%s\": %s"), argv[1], error->message);
+              g_error_free (error);
+            }
+          else
+            {
+              g_critical (_("The file \"%s\" contains no data"), argv[1]);
+            }
+
+          return EXIT_FAILURE;
+        }
+
+      /* load the data into the key file */
+      res = g_key_file_load_from_data (key_file, contents, length, G_KEY_FILE_KEEP_COMMENTS
+                                       | G_KEY_FILE_KEEP_TRANSLATIONS, &error);
+      g_free (contents);
+      if (G_UNLIKELY (!res))
+        {
+          /* failed to parse the file */
+          g_critical (_("Failed to parse contents of \"%s\": %s"), argv[1], error->message);
           g_error_free (error);
           return EXIT_FAILURE;
         }
     }
 
   /* determine the type of the desktop file */
-  value = g_key_file_get_string (key_file, "Desktop Entry", "Type", &error);
+  value = g_key_file_get_string (key_file, G_KEY_FILE_DESKTOP_GROUP,
+                                 G_KEY_FILE_DESKTOP_KEY_TYPE, NULL);
   if (G_UNLIKELY (value == NULL))
     {
       /* we cannot continue without a type */
-      g_fprintf (stderr, "%s: %s: %s\n", g_get_prgname (), argv[1], error->message);
-      g_error_free (error);
+      g_critical (_("File \"%s\" has no type key"), argv[1]);
       return EXIT_FAILURE;
     }
 
@@ -223,11 +254,7 @@ main (int argc, char **argv)
   if (G_UNLIKELY (enum_value == NULL))
     {
       /* tell the user that we don't support the type */
-      s = g_strdup_printf (_("Unsupported desktop file type \"%s\""), value);
-      g_fprintf (stderr, "%s: %s: %s\n", g_get_prgname (), argv[1], s);
-      g_free (s);
-
-      /* and fail */
+      g_critical (_("Unsupported desktop file type \"%s\""), value);
       return EXIT_FAILURE;
     }
   g_free (value);
@@ -239,7 +266,7 @@ main (int argc, char **argv)
                                                 NULL, GTK_DIALOG_NO_SEPARATOR,
                                                 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
                                                 NULL);
-  gtk_window_set_default_size (GTK_WINDOW (dialog), 450, 400);
+  gtk_window_set_default_size (GTK_WINDOW (dialog), 350, 375);
   gtk_window_set_icon_name (GTK_WINDOW (dialog), ICON_NAMES[mode]);
 
   /* add the "Create"/"Save" button (as default) */
@@ -258,17 +285,20 @@ main (int argc, char **argv)
   gtk_widget_show (editor);
 
   /* setup the name */
-  value = g_key_file_get_locale_string (key_file, "Desktop Entry", "Name", NULL, NULL);
+  value = g_key_file_get_locale_string (key_file, G_KEY_FILE_DESKTOP_GROUP,
+                                        G_KEY_FILE_DESKTOP_KEY_NAME, NULL, NULL);
   exo_die_editor_set_name (EXO_DIE_EDITOR (editor), (value != NULL) ? value : "");
   g_free (value);
 
   /* setup the comment */
-  value = g_key_file_get_locale_string (key_file, "Desktop Entry", "Comment", NULL, NULL);
+  value = g_key_file_get_locale_string (key_file, G_KEY_FILE_DESKTOP_GROUP,
+                                        G_KEY_FILE_DESKTOP_KEY_COMMENT, NULL, NULL);
   exo_die_editor_set_comment (EXO_DIE_EDITOR (editor), (value != NULL) ? value : "");
   g_free (value);
 
   /* setup the icon (automatically fixing broken icons) */
-  value = g_key_file_get_locale_string (key_file, "Desktop Entry", "Icon", NULL, NULL);
+  value = g_key_file_get_locale_string (key_file, G_KEY_FILE_DESKTOP_GROUP,
+                                        G_KEY_FILE_DESKTOP_KEY_ICON, NULL, NULL);
   if (value != NULL && !g_path_is_absolute (value))
     {
       /* check if this is an invalid icon declaration */
@@ -284,18 +314,24 @@ main (int argc, char **argv)
     {
     case EXO_DIE_EDITOR_MODE_APPLICATION:
       /* setup the command */
-      value = g_key_file_get_string (key_file, "Desktop Entry", "Exec", NULL);
+      value = g_key_file_get_string (key_file, G_KEY_FILE_DESKTOP_GROUP,
+                                     G_KEY_FILE_DESKTOP_KEY_EXEC, NULL);
       exo_die_editor_set_command (EXO_DIE_EDITOR (editor), (value != NULL) ? value : "");
       g_free (value);
 
       /* setup launcher options */
-      exo_die_editor_set_snotify (EXO_DIE_EDITOR (editor), g_key_file_get_boolean (key_file, "Desktop Entry", "StartupNotify", NULL));
-      exo_die_editor_set_terminal (EXO_DIE_EDITOR (editor), g_key_file_get_boolean (key_file, "Desktop Entry", "Terminal", NULL));
+      exo_die_editor_set_snotify (EXO_DIE_EDITOR (editor),
+          g_key_file_get_boolean (key_file, G_KEY_FILE_DESKTOP_GROUP,
+                                  G_KEY_FILE_DESKTOP_KEY_STARTUP_NOTIFY, NULL));
+      exo_die_editor_set_terminal (EXO_DIE_EDITOR (editor),
+          g_key_file_get_boolean (key_file, G_KEY_FILE_DESKTOP_GROUP,
+                                  G_KEY_FILE_DESKTOP_KEY_TERMINAL, NULL));
       break;
 
     case EXO_DIE_EDITOR_MODE_LINK:
       /* setup the URL */
-      value = g_key_file_get_string (key_file, "Desktop Entry", "URL", NULL);
+      value = g_key_file_get_string (key_file, G_KEY_FILE_DESKTOP_GROUP,
+                                     G_KEY_FILE_DESKTOP_KEY_URL, NULL);
       exo_die_editor_set_url (EXO_DIE_EDITOR (editor), (value != NULL) ? value : "");
       g_free (value);
       break;
@@ -322,33 +358,44 @@ main (int argc, char **argv)
     }
 #endif
 
-  /* default to base as file/foldername */
-  filename = g_strdup (argv[1]);
-
   /* run the dialog */
   response = gtk_dialog_run (GTK_DIALOG (dialog));
   if (response == GTK_RESPONSE_ACCEPT)
     {
       /* save common values (localized if possible) */
-      exo_die_g_key_file_set_locale_value (key_file, "Desktop Entry", "Name", exo_die_editor_get_name (EXO_DIE_EDITOR (editor)));
-      exo_die_g_key_file_set_locale_value (key_file, "Desktop Entry", "Icon", exo_die_editor_get_icon (EXO_DIE_EDITOR (editor)));
-      exo_die_g_key_file_set_locale_value (key_file, "Desktop Entry", "Comment", exo_die_editor_get_comment (EXO_DIE_EDITOR (editor)));
+      exo_die_g_key_file_set_locale_value (key_file, G_KEY_FILE_DESKTOP_GROUP,
+                                           G_KEY_FILE_DESKTOP_KEY_NAME,
+                                           exo_die_editor_get_name (EXO_DIE_EDITOR (editor)));
+      exo_die_g_key_file_set_locale_value (key_file, G_KEY_FILE_DESKTOP_GROUP,
+                                           G_KEY_FILE_DESKTOP_KEY_ICON,
+                                           exo_die_editor_get_icon (EXO_DIE_EDITOR (editor)));
+      exo_die_g_key_file_set_locale_value (key_file, G_KEY_FILE_DESKTOP_GROUP,
+                                           G_KEY_FILE_DESKTOP_KEY_COMMENT,
+                                           exo_die_editor_get_comment (EXO_DIE_EDITOR (editor)));
 
       /* save mode specific stuff */
       switch (mode)
         {
         case EXO_DIE_EDITOR_MODE_APPLICATION:
           /* save the new command */
-          g_key_file_set_string (key_file, "Desktop Entry", "Exec", exo_die_editor_get_command (EXO_DIE_EDITOR (editor)));
+          g_key_file_set_string (key_file, G_KEY_FILE_DESKTOP_GROUP,
+                                 G_KEY_FILE_DESKTOP_KEY_EXEC,
+                                 exo_die_editor_get_command (EXO_DIE_EDITOR (editor)));
 
           /* save the new launcher options */
-          g_key_file_set_boolean (key_file, "Desktop Entry", "Terminal", exo_die_editor_get_terminal (EXO_DIE_EDITOR (editor)));
-          g_key_file_set_boolean (key_file, "Desktop Entry", "StartupNotify", exo_die_editor_get_snotify (EXO_DIE_EDITOR (editor)));
+          g_key_file_set_boolean (key_file, G_KEY_FILE_DESKTOP_GROUP,
+                                 G_KEY_FILE_DESKTOP_KEY_TERMINAL,
+                                 exo_die_editor_get_terminal (EXO_DIE_EDITOR (editor)));
+          g_key_file_set_boolean (key_file, G_KEY_FILE_DESKTOP_GROUP,
+                                 G_KEY_FILE_DESKTOP_KEY_STARTUP_NOTIFY,
+                                 exo_die_editor_get_snotify (EXO_DIE_EDITOR (editor)));
           break;
 
         case EXO_DIE_EDITOR_MODE_LINK:
           /* save the new URL */
-          g_key_file_set_string (key_file, "Desktop Entry", "URL", exo_die_editor_get_url (EXO_DIE_EDITOR (editor)));
+          g_key_file_set_string (key_file, G_KEY_FILE_DESKTOP_GROUP,
+                                 G_KEY_FILE_DESKTOP_KEY_URL,
+                                 exo_die_editor_get_url (EXO_DIE_EDITOR (editor)));
           break;
 
         default:
@@ -357,7 +404,7 @@ main (int argc, char **argv)
         }
 
       /* try to save the file */
-      if (!exo_die_g_key_file_save (key_file, opt_create_new, filename, &error) && opt_create_new)
+      if (!exo_die_g_key_file_save (key_file, opt_create_new, gfile, &error) && opt_create_new)
         {
           /* reset the error */
           g_clear_error (&error);
@@ -370,24 +417,28 @@ main (int argc, char **argv)
                                                  GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
                                                  NULL);
           gtk_file_chooser_set_local_only (GTK_FILE_CHOOSER (chooser), TRUE);
-#if GTK_CHECK_VERSION(2,8,0)
           gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (chooser), TRUE);
-#endif
+
+          file_type = g_file_query_file_type (gfile, G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS, NULL);
 
           /* if base is a folder, enter the folder */
-          if (g_file_test (filename, G_FILE_TEST_IS_DIR))
+          if (file_type == G_FILE_TYPE_DIRECTORY)
             {
-              gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (chooser), filename);
+              gtk_file_chooser_set_current_folder_file (GTK_FILE_CHOOSER (chooser), gfile, NULL);
               gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (chooser), "new-file.desktop");
             }
-          else if (g_path_is_absolute (filename))
+          else if (file_type == G_FILE_TYPE_REGULAR)
             {
-              dirname = g_path_get_dirname (filename);
-              basename = g_path_get_basename (filename);
-              gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (chooser), dirname);
-              gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (chooser), basename);
-              g_free (basename);
-              g_free (dirname);
+              gfile_parent = g_file_get_parent (gfile);
+              if (G_LIKELY (gfile_parent != NULL))
+                {
+                  gtk_file_chooser_set_current_folder_file (GTK_FILE_CHOOSER (chooser), gfile_parent, NULL);
+                  g_object_unref (G_OBJECT (gfile_parent));
+                }
+
+              base_name = g_file_get_basename (gfile);
+              gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (chooser), base_name);
+              g_free (base_name);
             }
 
           /* run the chooser */
@@ -395,13 +446,12 @@ main (int argc, char **argv)
           if (G_LIKELY (response == GTK_RESPONSE_ACCEPT))
             {
               /* release the previous file name */
-              g_free (filename);
-
-              /* determine the new file name */
-              filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (chooser));
+              if (G_LIKELY (gfile != NULL))
+                g_object_unref (G_OBJECT (gfile));
 
               /* try again to save to the new file */
-              exo_die_g_key_file_save (key_file, FALSE, filename, &error);
+              gfile = gtk_file_chooser_get_file (GTK_FILE_CHOOSER (chooser));
+              exo_die_g_key_file_save (key_file, FALSE, gfile, &error);
             }
 
           /* destroy the chooser */
@@ -412,16 +462,18 @@ main (int argc, char **argv)
       if (G_UNLIKELY (response == GTK_RESPONSE_ACCEPT && error != NULL))
         {
           /* display an error message to the user */
+          s = g_file_get_uri (gfile);
           message = gtk_message_dialog_new (GTK_WINDOW (dialog),
                                             GTK_DIALOG_DESTROY_WITH_PARENT
                                             | GTK_DIALOG_MODAL,
                                             GTK_MESSAGE_ERROR,
                                             GTK_BUTTONS_CLOSE,
                                             opt_create_new ? _("Failed to create \"%s\".") : _("Failed to save \"%s\"."),
-                                            filename);
+                                            s);
           gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (message), "%s.", error->message);
           gtk_dialog_run (GTK_DIALOG (message));
           gtk_widget_destroy (message);
+          g_free (s);
 
           /* jep, we failed */
           result = EXIT_FAILURE;
@@ -436,7 +488,7 @@ main (int argc, char **argv)
 
   /* cleanup */
   g_key_file_free (key_file);
-  g_free (filename);
+  g_object_unref (G_OBJECT (gfile));
 
   return result;
 }
