@@ -1,4 +1,4 @@
-/* $Id: main.c 28632 2008-11-06 11:25:05Z kelnos $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2003-2006 Benedikt Meurer <benny@xfce.org>.
  *
@@ -41,6 +41,7 @@ static const gchar *CATEGORY_EXEC_ERRORS[] =
 {
   N_("Failed to execute default Web Browser"),
   N_("Failed to execute default Mail Reader"),
+  N_("Failed to execute default File Manager"),
   N_("Failed to execute default Terminal Emulator"),
 };
 
@@ -66,8 +67,8 @@ main (int argc, char **argv)
   GOptionEntry       option_entries[] = {
     { "version", 'V', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE, &opt_version, N_("Print version information and exit"), NULL, },
     { "configure", 'c', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE, &opt_configure, N_("Open the Preferred Applications\nconfiguration dialog"), NULL, },
-    { "launch", 'l', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_STRING, &opt_launch_type, N_("Launch the default helper of TYPE with the optional PARAMETER, where TYPE is one of the following values."), N_("TYPE [PARAMETER]"), },
     { "socket-id", 's', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_INT, &opt_socket_id, N_("Settings manager socket"), N_("SOCKET ID"), },
+    { "launch", 'l', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_STRING, &opt_launch_type, N_("Launch the default helper of TYPE with the optional PARAMETER, where TYPE is one of the following values."), N_("TYPE [PARAMETER]"), },
     { NULL, },
   };
 
@@ -86,13 +87,15 @@ main (int argc, char **argv)
   g_option_context_add_group (opt_ctx, gtk_option_group);
 
   g_option_context_add_main_entries (opt_ctx, option_entries, NULL);
-  /* Note to Translators: Do not translate the TYPEs (WebBrowser, MailReader, TerminalEmulator),
-   * since the exo-helper utility will not accept localized TYPEs.
+  /* Note to Translators: Do not translate the TYPEs (WebBrowser, MailReader,
+   * FileManager and TerminalEmulator), since the exo-helper utility will
+   * not accept localized TYPEs.
    */
   g_option_context_set_description (opt_ctx,
                                     _("The following TYPEs are supported for the --launch command:\n\n"
                                       "  WebBrowser       - The preferred Web Browser.\n"
                                       "  MailReader       - The preferred Mail Reader.\n"
+                                      "  FileManager      - The preferred File Manager.\n"
                                       "  TerminalEmulator - The preferred Terminal Emulator."));
 
   if (!g_option_context_parse (opt_ctx, &argc, &argv, &error))
@@ -131,6 +134,9 @@ main (int argc, char **argv)
           gtk_widget_reparent (plug_child, plug);
           gtk_widget_show (plug_child);
 
+          /* End startup notification */
+          gdk_notify_startup_complete ();
+
           gtk_main ();
           gtk_widget_destroy (plug);
         }
@@ -162,6 +168,10 @@ main (int argc, char **argv)
           if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK)
             helper = exo_helper_database_get_default (database, category);
           gtk_widget_destroy (dialog);
+
+          /* iterate the mainloop until the dialog is fully destroyed */
+          while (gtk_events_pending ())
+            gtk_main_iteration ();
         }
 
       /* release our reference on the database */
@@ -200,11 +210,8 @@ main (int argc, char **argv)
   else
     {
       result = EXIT_FAILURE;
-#if GLIB_CHECK_VERSION(2, 14, 0)
+
       g_printerr ("%s", g_option_context_get_help (opt_ctx, FALSE, NULL));
-#else
-      g_printerr (_("Unknown helper arguments.\n"));
-#endif
     }
 
   g_option_context_free (opt_ctx);
