@@ -821,7 +821,7 @@ exo_mount_hal_device_mount (ExoMountHalDevice *device,
     }
 
   /* make sure that the mount point is usable (i.e. does not contain G_DIR_SEPARATOR's) */
-  if (mount_point != NULL && *mount_point != '\0')
+  if (!exo_str_is_empty (mount_point))
     mount_point = exo_str_replace (mount_point, G_DIR_SEPARATOR_S, "_");
   else
     mount_point = g_strdup ("");
@@ -854,7 +854,7 @@ oom:      g_set_error (error, G_FILE_ERROR, G_FILE_ERROR_NOMEM, "%s", g_strerror
                                      DBUS_TYPE_STRING, &mount_point,
                                      DBUS_TYPE_STRING, &fstype,
                                      DBUS_TYPE_ARRAY, DBUS_TYPE_STRING, &options, n,
-				                             DBUS_TYPE_INVALID))
+                                     DBUS_TYPE_INVALID))
         {
           dbus_message_unref (message);
           goto oom;
@@ -987,8 +987,8 @@ oom:      g_set_error (error, G_FILE_ERROR, G_FILE_ERROR_NOMEM, "%s", g_strerror
             {
               /* TRANSLATORS: User tried to mount an Audio CD that doesn't contain a data track. */
               g_set_error (error, G_FILE_ERROR, G_FILE_ERROR_FAILED,
-                           _("Audio CDs cannot be mounted, use "
-                             "Xfmedia to play the audio tracks"));
+                           _("Audio CDs cannot be mounted, use your favorite audio "
+                             "player to play the audio tracks"));
             }
           else
             {
