@@ -31,10 +31,42 @@
 
 G_BEGIN_DECLS
 
+/**
+ * EXO_MAJOR_VERSION:
+ *
+ * Like #exo_major_version, but from the headers used at application
+ * compile time, rather than from the library linked against at
+ * application run time.
+ **/
 #define EXO_MAJOR_VERSION 0
-#define EXO_MINOR_VERSION 3
-#define EXO_MICRO_VERSION 102
 
+/**
+ * EXO_MINOR_VERSION:
+ *
+ * Like #exo_minor_version, but from the headers used at application
+ * compile time, rather than from the library linked against at
+ * application run time.
+ **/
+#define EXO_MINOR_VERSION 5
+
+/**
+ * EXO_MICRO_VERSION:
+ *
+ * Like #exo_micro_version, but from the headers used at application
+ * compile time, rather than from the library linked against at
+ * application run time.
+ **/
+#define EXO_MICRO_VERSION 0
+
+/**
+ * EXO_CHECK_VERSION:
+ * @major: major version (e.g. 1 for version 1.2.3)
+ * @minor: minor version (e.g. 2 for version 1.2.3)
+ * @micro: micro version (e.g. 3 for version 1.2.3)
+ *
+ * Returns: %TRUE if the version of the exo header files is equal or
+ *          better than the passed-in version.
+ **/
 #define EXO_CHECK_VERSION(major,minor,micro) \
   (EXO_MAJOR_VERSION > (major) \
    || (EXO_MAJOR_VERSION == (major) \
@@ -69,25 +101,10 @@ const gchar *exo_check_version (guint required_major,
 #endif /* __GNUC__ */
 #endif /* !defined(G_GNUC_WARN_UNUSED_RESULT) */
 
-/* with GObject >= 2.7.0, copying name, nick and blurb can be avoided */
-#if GLIB_CHECK_VERSION(2,7,0)
-#define EXO_PARAM_READABLE  (G_PARAM_READABLE \
-                           | G_PARAM_STATIC_NAME \
-                           | G_PARAM_STATIC_NICK \
-                           | G_PARAM_STATIC_BLURB)
-#define EXO_PARAM_WRITABLE  (G_PARAM_WRITABLE \
-                           | G_PARAM_STATIC_NAME \
-                           | G_PARAM_STATIC_NICK \
-                           | G_PARAM_STATIC_BLURB)
-#define EXO_PARAM_READWRITE (G_PARAM_READWRITE \
-                           | G_PARAM_STATIC_NAME \
-                           | G_PARAM_STATIC_NICK \
-                           | G_PARAM_STATIC_BLURB)
-#else
-#define EXO_PARAM_READABLE  (G_PARAM_READABLE)
-#define EXO_PARAM_WRITABLE  (G_PARAM_WRITABLE)
-#define EXO_PARAM_READWRITE (G_PARAM_READWRITE)
-#endif
+/* shorter macros for the GParamSpecs with static strings */
+#define EXO_PARAM_READABLE  (G_PARAM_READABLE | G_PARAM_STATIC_STRINGS)
+#define EXO_PARAM_WRITABLE  (G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS)
+#define EXO_PARAM_READWRITE (G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS)
 
 G_END_DECLS
 
