@@ -1,4 +1,4 @@
-/* $Id: exo-gdk-pixbuf-extensions.c 22884 2006-08-26 12:40:43Z benny $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2004-2006 os-cillation e.K.
  *
@@ -74,25 +74,35 @@
 #define _O_BINARY 0
 #endif
 
+/**
+ * SECTION: exo-gdk-pixbuf-extensions
+ * @title: Extensions to gdk-pixbuf
+ * @short_description: Miscelleanous extensions to the gdk-pixbuf library
+ * @include: exo/exo.h
+ *
+ * This facility includes several functions to extend the basic functionality
+ * provided by the gdk-pixbuf library.
+ **/
+
 
 
 /**
  * exo_gdk_pixbuf_colorize:
- * @src   : the source #GdkPixbuf.
- * @color : the new color.
+ * @source : the source #GdkPixbuf.
+ * @color  : the new color.
  *
- * Creates a new #GdkPixbuf based on @src, which is
+ * Creates a new #GdkPixbuf based on @source, which is
  * colorized to @color.
  *
  * The caller is responsible to free the returned object
  * using g_object_unref() when no longer needed.
  *
- * Return value: the colorized #GdkPixbuf.
+ * Returns: the colorized #GdkPixbuf.
  *
  * Since: 0.3.1.3
  **/
 GdkPixbuf*
-exo_gdk_pixbuf_colorize (const GdkPixbuf *src,
+exo_gdk_pixbuf_colorize (const GdkPixbuf *source,
                          const GdkColor  *color)
 {
   GdkPixbuf *dst;
@@ -104,23 +114,23 @@ exo_gdk_pixbuf_colorize (const GdkPixbuf *src,
   gint       i;
 
   /* determine source parameters */
-  width = gdk_pixbuf_get_width (src);
-  height = gdk_pixbuf_get_height (src);
-  has_alpha = gdk_pixbuf_get_has_alpha (src);
+  width = gdk_pixbuf_get_width (source);
+  height = gdk_pixbuf_get_height (source);
+  has_alpha = gdk_pixbuf_get_has_alpha (source);
 
   /* allocate the destination pixbuf */
-  dst = gdk_pixbuf_new (gdk_pixbuf_get_colorspace (src), has_alpha, gdk_pixbuf_get_bits_per_sample (src), width, height);
+  dst = gdk_pixbuf_new (gdk_pixbuf_get_colorspace (source), has_alpha, gdk_pixbuf_get_bits_per_sample (source), width, height);
 
   /* determine row strides on src/dst */
   dst_row_stride = gdk_pixbuf_get_rowstride (dst);
-  src_row_stride = gdk_pixbuf_get_rowstride (src);
+  src_row_stride = gdk_pixbuf_get_rowstride (source);
 
 #if defined(__GNUC__) && defined(__MMX__)
   /* check if there's a good reason to use MMX */
   if (G_LIKELY (has_alpha && dst_row_stride == width * 4 && src_row_stride == width * 4 && (width * height) % 2 == 0))
     {
       __m64 *pixdst = (__m64 *) gdk_pixbuf_get_pixels (dst);
-      __m64 *pixsrc = (__m64 *) gdk_pixbuf_get_pixels (src);
+      __m64 *pixsrc = (__m64 *) gdk_pixbuf_get_pixels (source);
       __m64  alpha_mask = _mm_set_pi8 (0xff, 0, 0, 0, 0xff, 0, 0, 0);
       __m64  color_factor = _mm_set_pi16 (0, color->blue, color->green, color->red);
       __m64  zero = _mm_setzero_si64 ();
@@ -168,7 +178,7 @@ exo_gdk_pixbuf_colorize (const GdkPixbuf *src,
 #endif
     {
       guchar *dst_pixels = gdk_pixbuf_get_pixels (dst);
-      guchar *src_pixels = gdk_pixbuf_get_pixels (src);
+      guchar *src_pixels = gdk_pixbuf_get_pixels (source);
       guchar *pixdst;
       guchar *pixsrc;
       gint    red_value = color->red / 255.0;
@@ -186,7 +196,7 @@ exo_gdk_pixbuf_colorize (const GdkPixbuf *src,
               *pixdst++ = (*pixsrc++ * red_value) >> 8;
               *pixdst++ = (*pixsrc++ * green_value) >> 8;
               *pixdst++ = (*pixsrc++ * blue_value) >> 8;
-              
+
               if (has_alpha)
                 *pixdst++ = *pixsrc++;
             }
@@ -211,7 +221,7 @@ draw_frame_row (const GdkPixbuf *frame_image,
   gint remaining_width;
   gint slab_width;
   gint h_offset;
-  
+
   for (h_offset = 0, remaining_width = target_width; remaining_width > 0; h_offset += slab_width, remaining_width -= slab_width)
     {
       slab_width = (remaining_width > source_width) ? source_width : remaining_width;
@@ -234,7 +244,7 @@ draw_frame_column (const GdkPixbuf *frame_image,
   gint remaining_height;
   gint slab_height;
   gint v_offset;
-  
+
   for (v_offset = 0, remaining_height = target_height; remaining_height > 0; v_offset += slab_height, remaining_height -= slab_height)
     {
       slab_height = (remaining_height > source_height) ? source_height : remaining_height;
@@ -246,23 +256,23 @@ draw_frame_column (const GdkPixbuf *frame_image,
 
 /**
  * exo_gdk_pixbuf_frame:
- * @src           : the source #GdkPixbuf.
+ * @source        : the source #GdkPixbuf.
  * @frame         : the frame #GdkPixbuf.
  * @left_offset   : the left frame offset.
  * @top_offset    : the top frame offset.
  * @right_offset  : the right frame offset.
  * @bottom_offset : the bottom frame offset.
  *
- * Embeds @src in @frame and returns the result as new #GdkPixbuf.
+ * Embeds @source in @frame and returns the result as new #GdkPixbuf.
  *
  * The caller is responsible to free the returned #GdkPixbuf using g_object_unref().
  *
- * Return value: the framed version of @src.
+ * Returns: the framed version of @source.
  *
  * Since: 0.3.1.9
  **/
 GdkPixbuf*
-exo_gdk_pixbuf_frame (const GdkPixbuf *src,
+exo_gdk_pixbuf_frame (const GdkPixbuf *source,
                       const GdkPixbuf *frame,
                       gint             left_offset,
                       gint             top_offset,
@@ -278,10 +288,10 @@ exo_gdk_pixbuf_frame (const GdkPixbuf *src,
   gint       src_height;
 
   g_return_val_if_fail (GDK_IS_PIXBUF (frame), NULL);
-  g_return_val_if_fail (GDK_IS_PIXBUF (src), NULL);
+  g_return_val_if_fail (GDK_IS_PIXBUF (source), NULL);
 
-  src_width = gdk_pixbuf_get_width (src);
-  src_height = gdk_pixbuf_get_height (src);
+  src_width = gdk_pixbuf_get_width (source);
+  src_height = gdk_pixbuf_get_height (source);
 
   frame_width = gdk_pixbuf_get_width (frame);
   frame_height = gdk_pixbuf_get_height (frame);
@@ -293,7 +303,7 @@ exo_gdk_pixbuf_frame (const GdkPixbuf *src,
   dst = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, dst_width, dst_height);
 
   /* fill the destination if the source has an alpha channel */
-  if (G_UNLIKELY (gdk_pixbuf_get_has_alpha (src)))
+  if (G_UNLIKELY (gdk_pixbuf_get_has_alpha (source)))
     gdk_pixbuf_fill (dst, 0xffffffff);
 
   /* draw the left top cornder and top row */
@@ -316,7 +326,7 @@ exo_gdk_pixbuf_frame (const GdkPixbuf *src,
                      dst_width - right_offset, dst, top_offset, right_offset);
 
   /* copy the source pixbuf into the framed area */
-  gdk_pixbuf_copy_area (src, 0, 0, src_width, src_height, dst, left_offset, top_offset);
+  gdk_pixbuf_copy_area (source, 0, 0, src_width, src_height, dst, left_offset, top_offset);
 
   return dst;
 }
@@ -325,21 +335,21 @@ exo_gdk_pixbuf_frame (const GdkPixbuf *src,
 
 /**
  * exo_gdk_pixbuf_lucent:
- * @src     : the source #GdkPixbuf.
+ * @source  : the source #GdkPixbuf.
  * @percent : the percentage of translucency.
  *
- * Returns a version of @src, whose pixels translucency is
- * @percent of the original @src pixels.
+ * Returns a version of @source, whose pixels translucency is
+ * @percent of the original @source pixels.
  *
  * The caller is responsible to free the returned object
  * using g_object_unref() when no longer needed.
  *
- * Return value: a translucent version of @src.
+ * Returns: a translucent version of @source.
  *
  * Since: 0.3.1.3
  **/
 GdkPixbuf*
-exo_gdk_pixbuf_lucent (const GdkPixbuf *src,
+exo_gdk_pixbuf_lucent (const GdkPixbuf *source,
                        guint            percent)
 {
   GdkPixbuf *dst;
@@ -353,26 +363,26 @@ exo_gdk_pixbuf_lucent (const GdkPixbuf *src,
   gint       height;
   gint       i, j;
 
-  g_return_val_if_fail (GDK_IS_PIXBUF (src), NULL);
-  g_return_val_if_fail (percent >= 0 && percent <= 100, NULL);
+  g_return_val_if_fail (GDK_IS_PIXBUF (source), NULL);
+  g_return_val_if_fail ((gint) percent >= 0 && percent <= 100, NULL);
 
   /* determine source parameters */
-  width = gdk_pixbuf_get_width (src);
-  height = gdk_pixbuf_get_height (src);
+  width = gdk_pixbuf_get_width (source);
+  height = gdk_pixbuf_get_height (source);
 
   /* allocate the destination pixbuf */
-  dst = gdk_pixbuf_new (gdk_pixbuf_get_colorspace (src), TRUE, gdk_pixbuf_get_bits_per_sample (src), width, height);
+  dst = gdk_pixbuf_new (gdk_pixbuf_get_colorspace (source), TRUE, gdk_pixbuf_get_bits_per_sample (source), width, height);
 
   /* determine row strides on src/dst */
   dst_row_stride = gdk_pixbuf_get_rowstride (dst);
-  src_row_stride = gdk_pixbuf_get_rowstride (src);
+  src_row_stride = gdk_pixbuf_get_rowstride (source);
 
   /* determine pixels on src/dst */
   dst_pixels = gdk_pixbuf_get_pixels (dst);
-  src_pixels = gdk_pixbuf_get_pixels (src);
+  src_pixels = gdk_pixbuf_get_pixels (source);
 
   /* check if the source already contains an alpha channel */
-  if (G_LIKELY (gdk_pixbuf_get_has_alpha (src)))
+  if (G_LIKELY (gdk_pixbuf_get_has_alpha (source)))
     {
       for (i = height; --i >= 0; )
         {
@@ -429,20 +439,20 @@ lighten_channel (guchar cur_value)
 
 /**
  * exo_gdk_pixbuf_spotlight:
- * @src : the source #GdkPixbuf.
+ * @source : the source #GdkPixbuf.
  *
- * Creates a lightened version of @src, suitable for
+ * Creates a lightened version of @source, suitable for
  * prelit state display of icons.
  *
  * The caller is responsible to free the returned
  * pixbuf using #g_object_unref().
  *
- * Return value: the lightened version of @src.
+ * Returns: the lightened version of @source.
  *
  * Since: 0.3.1.3
  **/
 GdkPixbuf*
-exo_gdk_pixbuf_spotlight (const GdkPixbuf *src)
+exo_gdk_pixbuf_spotlight (const GdkPixbuf *source)
 {
   GdkPixbuf *dst;
   gboolean   has_alpha;
@@ -453,23 +463,23 @@ exo_gdk_pixbuf_spotlight (const GdkPixbuf *src)
   gint       i;
 
   /* determine source parameters */
-  width = gdk_pixbuf_get_width (src);
-  height = gdk_pixbuf_get_height (src);
-  has_alpha = gdk_pixbuf_get_has_alpha (src);
+  width = gdk_pixbuf_get_width (source);
+  height = gdk_pixbuf_get_height (source);
+  has_alpha = gdk_pixbuf_get_has_alpha (source);
 
   /* allocate the destination pixbuf */
-  dst = gdk_pixbuf_new (gdk_pixbuf_get_colorspace (src), has_alpha, gdk_pixbuf_get_bits_per_sample (src), width, height);
+  dst = gdk_pixbuf_new (gdk_pixbuf_get_colorspace (source), has_alpha, gdk_pixbuf_get_bits_per_sample (source), width, height);
 
   /* determine src/dst row strides */
   dst_row_stride = gdk_pixbuf_get_rowstride (dst);
-  src_row_stride = gdk_pixbuf_get_rowstride (src);
-  
+  src_row_stride = gdk_pixbuf_get_rowstride (source);
+
 #if defined(__GNUC__) && defined(__MMX__)
   /* check if there's a good reason to use MMX */
   if (G_LIKELY (has_alpha && dst_row_stride == width * 4 && src_row_stride == width * 4 && (width * height) % 2 == 0))
     {
       __m64 *pixdst = (__m64 *) gdk_pixbuf_get_pixels (dst);
-      __m64 *pixsrc = (__m64 *) gdk_pixbuf_get_pixels (src);
+      __m64 *pixsrc = (__m64 *) gdk_pixbuf_get_pixels (source);
       __m64  alpha_mask = _mm_set_pi8 (0xff, 0, 0, 0, 0xff, 0, 0, 0);
       __m64  twentyfour = _mm_set_pi8 (0, 24, 24, 24, 0, 24, 24, 24);
       __m64  zero = _mm_setzero_si64 ();
@@ -517,7 +527,7 @@ exo_gdk_pixbuf_spotlight (const GdkPixbuf *src)
 #endif
     {
       guchar *dst_pixels = gdk_pixbuf_get_pixels (dst);
-      guchar *src_pixels = gdk_pixbuf_get_pixels (src);
+      guchar *src_pixels = gdk_pixbuf_get_pixels (source);
       guchar *pixdst;
       guchar *pixsrc;
       gint    j;
@@ -526,7 +536,7 @@ exo_gdk_pixbuf_spotlight (const GdkPixbuf *src)
         {
           pixdst = dst_pixels + i * dst_row_stride;
           pixsrc = src_pixels + i * src_row_stride;
-      
+
           for (j = width; j > 0; --j)
             {
               *pixdst++ = lighten_channel (*pixsrc++);
@@ -563,7 +573,7 @@ exo_gdk_pixbuf_spotlight (const GdkPixbuf *src)
  * The caller is responsible to free the returned #GdkPixbuf
  * using g_object_unref() when no longer needed.
  *
- * Return value: the resulting #GdkPixbuf.
+ * Returns: the resulting #GdkPixbuf.
  *
  * Since: 0.3.1.1
  **/
@@ -615,7 +625,7 @@ exo_gdk_pixbuf_scale_down (GdkPixbuf *source,
  * Scales @source to @dest_size while preserving the aspect ratio of
  * @source.
  *
- * Return value: A newly created #GdkPixbuf.
+ * Returns: A newly created #GdkPixbuf.
  **/
 GdkPixbuf*
 exo_gdk_pixbuf_scale_ratio (GdkPixbuf *source,
@@ -713,23 +723,31 @@ size_prepared (GdkPixbufLoader  *loader,
 
 /**
  * exo_gdk_pixbuf_new_from_file_at_max_size:
- * @filename              : name of the file to load, in the GLib file name encoding.
+ * @filename              : name of the file to load, in the GLib file
+ *                          name encoding.
  * @max_width             : the maximum width of the loaded image.
  * @max_height            : the maximum height of the loaded image.
- * @preserve_aspect_ratio : %TRUE to preserve the image's aspect ratio while scaling to fit into @max_width and @max_height.
+ * @preserve_aspect_ratio : %TRUE to preserve the image's aspect ratio
+ *                          while scaling to fit into @max_width and @max_height.
  * @error                 : return location for errors or %NULL.
  *
- * Creates a new #GdkPixbuf by loading an image from the file at @filename. The file format is detected automatically. If %NULL
- * is returned, then @error will be set. Possible errors are in the #GDK_PIXBUF_ERROR and #G_FILE_ERROR domains. If the image
- * dimensions exceed @max_width or @max_height, the image will be scaled down to fit into the dimensions, optionally preserving
- * the image's aspect ratio. The image may still be larger, depending on the loader.
+ * Creates a new #GdkPixbuf by loading an image from the file at
+ * @filename. The file format is detected automatically. If %NULL is
+ * returned, then @error will be set. Possible errors are in the
+ * #GDK_PIXBUF_ERROR and #G_FILE_ERROR domains. If the image dimensions
+ * exceed @max_width or @max_height, the image will be scaled down to
+ * fit into the dimensions, optionally preservingthe image's aspect
+ * ratio. The image may still be larger, depending on the loader.
  *
- * The advantage of using this function over gdk_pixbuf_new_from_file_at_scale() is that images will never be scaled up, which
- * would otherwise result in ugly images.
+ * The advantage of using this function over
+ * gdk_pixbuf_new_from_file_at_scale() is that images will never be
+ * scaled up, whichwould otherwise result in ugly images.
  *
- * Return value: a newly created #GdkPixbuf with a reference count or 1, or %NULL if any of several error conditions occurred:
- *               the file could not be opened, there was no loader for the file's format, there was not enough memory to allocate
- *               the buffer for the image, or the image file contained invalid data.
+ * Returns: a newly created #GdkPixbuf with a reference count or 1, or
+ *          %NULL if any of several error conditions occurred: the file
+ *          could not be opened, there was no loader for the file's format,
+ *          there was not enough memory to allocate the buffer for the
+ *          image, or the image file contained invalid data.
  *
  * Since: 0.3.1.9
  **/
