@@ -1,4 +1,4 @@
-/* $Id: exo-icon-bar.c 22527 2006-07-25 23:03:26Z benny $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2004-2006 os-cillation e.K.
  *
@@ -31,6 +31,56 @@
 #include <exo/exo-string.h>
 #include <exo/exo-alias.h>
 
+/**
+ * SECTION: exo-icon-bar
+ * @title: ExoIconBar
+ * @short_description: A widget for displaying icon bars
+ * @include: exo/exo.h
+ * @see_also: <ulink url="http://library.gnome.org/devel/gtk/stable/GtkTreeModel.html">
+ *            GtkTreeModel</ulink>,
+ *            <ulink url="http://library.gnome.org/devel/gtk/stable/TreeWidget.html">
+ *            Tree and List Widget Overview</ulink>
+ *
+ * A widget that displays any object that implements the #GtkTreeModel interface
+ * in an icon bar.
+ *
+ * <example>
+ * <title>
+ *   Creating a new <structname>ExoIconBar</structname> with a <structname>GtkListStore</structname>
+ * </title>
+ * <programlisting>
+ * enum
+ * {
+ *   PIXBUF_COLUMN,
+ *   STRING_COLUMN,
+ *   N_COLUMNS,
+ * };
+ *
+ * {
+ *   GtkListStore *store;
+ *   GtkWidget    *bar;
+ *
+ *   // make a new list store
+ *   store = gtk_list_store_new (N_COLUMNS, GDK_TYPE_PIXBUF, G_TYPE_STRING);
+ *
+ *   // fill the store with data
+ *   fill_store (store);
+ *
+ *   // create the icon bar
+ *   bar = exo_icon_bar_new_with_model (GTK_TREE_MODEL (store));
+ *   exo_icon_bar_set_pixbuf_column (EXO_ICON_BAR (bar), PIXBUF_COLUMN);
+ *   exo_icon_bar_set_text_column (EXO_ICON_BAR (bar), TEXT_COLUMN);
+ *   gtk_widget_show (bar);
+ *
+ *   // the icon bar keeps a reference on the store now
+ *   g_object_unref (G_OBJECT (store));
+ *
+ *   // add the bar to your GUI now...
+ * }
+ * </programlisting>
+ * </example>
+ **/
+
 
 
 #define MINIMUM_ICON_ITEM_WIDTH 32
@@ -64,8 +114,6 @@ enum
 
 
 
-static void            exo_icon_bar_class_init            (ExoIconBarClass  *klass);
-static void            exo_icon_bar_init                  (ExoIconBar       *icon_bar);
 static void            exo_icon_bar_destroy               (GtkObject        *object);
 static void            exo_icon_bar_finalize              (GObject          *object);
 static void            exo_icon_bar_get_property          (GObject          *object,
@@ -179,28 +227,11 @@ struct _ExoIconBarPrivate
 
 
 
-static GObjectClass *exo_icon_bar_parent_class;
-static guint         icon_bar_signals[LAST_SIGNAL];
+static guint icon_bar_signals[LAST_SIGNAL];
 
 
 
-GType
-exo_icon_bar_get_type (void)
-{
-  static GType type = G_TYPE_INVALID;
-
-  if (G_UNLIKELY (type == G_TYPE_INVALID))
-    {
-      type = _exo_g_type_register_simple (GTK_TYPE_CONTAINER,
-                                          "ExoIconBar",
-                                          sizeof (ExoIconBarClass),
-                                          exo_icon_bar_class_init,
-                                          sizeof (ExoIconBar),
-                                          exo_icon_bar_init);
-    }
-
-  return type;
-}
+G_DEFINE_TYPE (ExoIconBar, exo_icon_bar, GTK_TYPE_CONTAINER)
 
 
 
@@ -213,8 +244,6 @@ exo_icon_bar_class_init (ExoIconBarClass *klass)
 
   g_type_class_add_private (klass, sizeof (ExoIconBarPrivate));
 
-  exo_icon_bar_parent_class = g_type_class_peek_parent (klass);
-
   gobject_class = G_OBJECT_CLASS (klass);
   gobject_class->finalize = exo_icon_bar_finalize;
   gobject_class->get_property = exo_icon_bar_get_property;
@@ -846,7 +875,7 @@ exo_icon_bar_set_adjustments (ExoIconBar    *icon_bar,
       gtk_object_sink (GTK_OBJECT (icon_bar->priv->vadjustment));
 
       g_signal_connect (icon_bar->priv->vadjustment, "value_changed",
-			                  G_CALLBACK (exo_icon_bar_adjustment_changed), icon_bar);
+                        G_CALLBACK (exo_icon_bar_adjustment_changed), icon_bar);
       need_adjust = TRUE;
     }
 
@@ -1244,7 +1273,7 @@ exo_icon_bar_item_new (void)
 {
   ExoIconBarItem *item;
 
-  item = _exo_slice_new0 (ExoIconBarItem);
+  item = g_slice_new0 (ExoIconBarItem);
   item->width = -1;
   item->height = -1;
 
@@ -1256,7 +1285,7 @@ exo_icon_bar_item_new (void)
 static void
 exo_icon_bar_item_free (ExoIconBarItem *item)
 {
-  _exo_slice_free (ExoIconBarItem, item);
+  g_slice_free (ExoIconBarItem, item);
 }
 
 
@@ -1303,10 +1332,10 @@ exo_icon_bar_row_changed (GtkTreeModel *model,
                           ExoIconBar   *icon_bar)
 {
   ExoIconBarItem  *item;
-  gint             index;
+  gint             idx;
 
-  index = gtk_tree_path_get_indices (path)[0];
-  item = g_list_nth (icon_bar->priv->items, index)->data;
+  idx = gtk_tree_path_get_indices (path)[0];
+  item = g_list_nth (icon_bar->priv->items, idx)->data;
   exo_icon_bar_item_invalidate (item);
   gtk_widget_queue_resize (GTK_WIDGET (icon_bar));
 }
@@ -1321,18 +1350,18 @@ exo_icon_bar_row_inserted (GtkTreeModel *model,
 {
   ExoIconBarItem  *item;
   GList           *lp;
-  gint             index;
+  gint             idx;
 
-  index = gtk_tree_path_get_indices (path)[0];
+  idx = gtk_tree_path_get_indices (path)[0];
   item = exo_icon_bar_item_new ();
 
   if ((gtk_tree_model_get_flags (icon_bar->priv->model) & GTK_TREE_MODEL_ITERS_PERSIST) != 0)
     item->iter = *iter;
-  item->index = index;
+  item->index = idx;
 
-  icon_bar->priv->items = g_list_insert (icon_bar->priv->items, item, index);
+  icon_bar->priv->items = g_list_insert (icon_bar->priv->items, item, idx);
 
-  for (lp = g_list_nth (icon_bar->priv->items, index + 1); lp != NULL; lp = lp->next)
+  for (lp = g_list_nth (icon_bar->priv->items, idx + 1); lp != NULL; lp = lp->next)
     {
       item = lp->data;
       item->index++;
@@ -1353,10 +1382,10 @@ exo_icon_bar_row_deleted (GtkTreeModel *model,
   gboolean        active = FALSE;
   GList          *lnext;
   GList          *lp;
-  gint            index;
+  gint            idx;
 
-  index = gtk_tree_path_get_indices (path)[0];
-  lp = g_list_nth (icon_bar->priv->items, index);
+  idx = gtk_tree_path_get_indices (path)[0];
+  lp = g_list_nth (icon_bar->priv->items, idx);
   item = lp->data;
 
   if (item == icon_bar->priv->active_item)
@@ -1431,7 +1460,9 @@ exo_icon_bar_rows_reordered (GtkTreeModel *model,
 /**
  * exo_icon_bar_new:
  *
- * Return value: a newly allocated #ExoIconBar.
+ * Creates a new #ExoIconBar without model.
+ *
+ * Returns: a newly allocated #ExoIconBar.
  **/
 GtkWidget*
 exo_icon_bar_new (void)
@@ -1448,8 +1479,7 @@ exo_icon_bar_new (void)
  * Creates a new #ExoIconBar and associates it with
  * @model.
  *
- * Return value: a newly allocated #ExoIconBar, which
- *               is associated with @model.
+ * Returns: a newly allocated #ExoIconBar, which is associated with @model.
  **/
 GtkWidget*
 exo_icon_bar_new_with_model (GtkTreeModel *model)
@@ -1469,8 +1499,8 @@ exo_icon_bar_new_with_model (GtkTreeModel *model)
  *
  * Returns the model the #ExoIconBar is based on. Returns %NULL if
  * the model is unset.
- * 
- * Return value: A #GtkTreeModel, or %NULL if none is currently being used.
+ *
+ * Returns: A #GtkTreeModel, or %NULL if none is currently being used.
  **/
 GtkTreeModel*
 exo_icon_bar_get_model (ExoIconBar *icon_bar)
@@ -1581,7 +1611,7 @@ exo_icon_bar_set_model (ExoIconBar    *icon_bar,
  *
  * Returns the column with pixbufs for @icon_bar.
  *
- * Return value: the pixbuf column, or -1 if it's unset.
+ * Returns: the pixbuf column, or -1 if it's unset.
  **/
 gint
 exo_icon_bar_get_pixbuf_column (ExoIconBar *icon_bar)
@@ -1639,7 +1669,7 @@ exo_icon_bar_set_pixbuf_column (ExoIconBar *icon_bar,
  *
  * Returns the column with text for @icon_bar.
  *
- * Return value: the text column, or -1 if it's unset.
+ * Returns: the text column, or -1 if it's unset.
  **/
 gint
 exo_icon_bar_get_text_column (ExoIconBar *icon_bar)
@@ -1699,7 +1729,7 @@ exo_icon_bar_set_text_column (ExoIconBar *icon_bar,
  * Retrieves the current orientation of the toolbar. See
  * exo_icon_bar_set_orientation().
  *
- * Return value: The orientation of @icon_bar.
+ * Returns: The orientation of @icon_bar.
  **/
 GtkOrientation
 exo_icon_bar_get_orientation (ExoIconBar *icon_bar)
@@ -1741,8 +1771,8 @@ exo_icon_bar_set_orientation (ExoIconBar    *icon_bar,
  * Returns the index of the currently active item, or -1 if there's no
  * active item.
  *
- * Return value: An integer which is the index of the currently active item,
- *               or -1 if there's no active item.
+ * Returns: An integer which is the index of the currently active item,
+ *          or -1 if there's no active item.
  **/
 gint
 exo_icon_bar_get_active (ExoIconBar *icon_bar)
@@ -1759,24 +1789,24 @@ exo_icon_bar_get_active (ExoIconBar *icon_bar)
 /**
  * exo_icon_bar_set_active:
  * @icon_bar  : An #ExoIconBar.
- * @index     : An index in the model passed during construction,
+ * @idx       : An index in the model passed during construction,
  *              or -1 to have no active item.
  *
- * Sets the active item of @icon_bar to be the item at @index.
+ * Sets the active item of @icon_bar to be the item at @idx.
  **/
 void
 exo_icon_bar_set_active (ExoIconBar *icon_bar,
-                         gint        index)
+                         gint        idx)
 {
   g_return_if_fail (EXO_IS_ICON_BAR (icon_bar));
-  g_return_if_fail (index == -1 || g_list_nth (icon_bar->priv->items, index) != NULL);
+  g_return_if_fail (idx == -1 || g_list_nth (icon_bar->priv->items, idx) != NULL);
 
-  if ((icon_bar->priv->active_item == NULL && index == -1)
-      || (icon_bar->priv->active_item != NULL && index == icon_bar->priv->active_item->index))
+  if ((icon_bar->priv->active_item == NULL && idx == -1)
+      || (icon_bar->priv->active_item != NULL && idx == icon_bar->priv->active_item->index))
     return;
 
-  if (G_UNLIKELY (index >= 0))
-    icon_bar->priv->active_item = g_list_nth (icon_bar->priv->items, index)->data;
+  if (G_UNLIKELY (idx >= 0))
+    icon_bar->priv->active_item = g_list_nth (icon_bar->priv->items, idx)->data;
   else
     icon_bar->priv->active_item = NULL;
 
@@ -1794,7 +1824,7 @@ exo_icon_bar_set_active (ExoIconBar *icon_bar,
  *
  * Sets @iter to point to the current active item, if it exists.
  *
- * Return value: %TRUE if @iter was set.
+ * Returns: %TRUE if @iter was set.
  **/
 gboolean
 exo_icon_bar_get_active_iter (ExoIconBar  *icon_bar,
