@@ -1,4 +1,4 @@
-/* $Id: exo-icon-chooser-model.c 22884 2006-08-26 12:40:43Z benny $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2005-2006 Benedikt Meurer <benny@xfce.org>
  *
@@ -40,14 +40,12 @@ typedef struct _ExoIconChooserModelItem ExoIconChooserModelItem;
 
 
 
-static void               exo_icon_chooser_model_class_init         (ExoIconChooserModelClass  *klass);
 static void               exo_icon_chooser_model_tree_model_init    (GtkTreeModelIface         *iface);
-static void               exo_icon_chooser_model_init               (ExoIconChooserModel       *model);
 static void               exo_icon_chooser_model_finalize           (GObject                   *object);
 static GtkTreeModelFlags  exo_icon_chooser_model_get_flags          (GtkTreeModel              *tree_model);
 static gint               exo_icon_chooser_model_get_n_columns      (GtkTreeModel              *tree_model);
 static GType              exo_icon_chooser_model_get_column_type    (GtkTreeModel              *tree_model,
-                                                                     gint                       index);
+                                                                     gint                       idx);
 static gboolean           exo_icon_chooser_model_get_iter           (GtkTreeModel              *tree_model,
                                                                      GtkTreeIter               *iter,
                                                                      GtkTreePath               *path);
@@ -91,7 +89,7 @@ struct _ExoIconChooserModel
   GObject       __parent__;
   GtkIconTheme *icon_theme;
   GList        *items;
-  guint         stamp;
+  gint          stamp;
 };
 
 struct _ExoIconChooserModelItem
@@ -118,28 +116,10 @@ static const gchar CONTEXT_NAMES[][14] =
   "Status",         /* EXO_ICON_CHOOSER_CONTEXT_STATUS */
 };
 
-static GObjectClass *exo_icon_chooser_model_parent_class;
 
 
-
-GType
-_exo_icon_chooser_model_get_type (void)
-{
-  static GType type = G_TYPE_INVALID;
-
-  if (G_UNLIKELY (type == G_TYPE_INVALID))
-    {
-      type = _exo_g_type_register_simple (G_TYPE_OBJECT,
-                                          "ExoIconChooserModel",
-                                          sizeof (ExoIconChooserModelClass),
-                                          exo_icon_chooser_model_class_init,
-                                          sizeof (ExoIconChooserModel),
-                                          exo_icon_chooser_model_init);
-      _exo_g_type_add_interface_simple (type, GTK_TYPE_TREE_MODEL, (GInterfaceInitFunc) exo_icon_chooser_model_tree_model_init);
-    }
-
-  return type;
-}
+G_DEFINE_TYPE_WITH_CODE (ExoIconChooserModel, exo_icon_chooser_model, G_TYPE_OBJECT,
+  G_IMPLEMENT_INTERFACE (GTK_TYPE_TREE_MODEL, exo_icon_chooser_model_tree_model_init))
 
 
 
@@ -148,9 +128,6 @@ exo_icon_chooser_model_class_init (ExoIconChooserModelClass *klass)
 {
   GObjectClass *gobject_class;
 
-  /* determine the parent type class */
-  exo_icon_chooser_model_parent_class = g_type_class_peek_parent (klass);
-
   gobject_class = G_OBJECT_CLASS (klass);
   gobject_class->finalize = exo_icon_chooser_model_finalize;
 }
@@ -225,9 +202,9 @@ exo_icon_chooser_model_get_n_columns (GtkTreeModel *tree_model)
 
 static GType
 exo_icon_chooser_model_get_column_type (GtkTreeModel *tree_model,
-                                        gint          index)
+                                        gint          idx)
 {
-  switch (index)
+  switch (idx)
     {
     case EXO_ICON_CHOOSER_MODEL_COLUMN_CONTEXT:
       return G_TYPE_UINT;
@@ -273,15 +250,15 @@ exo_icon_chooser_model_get_path (GtkTreeModel *tree_model,
                                  GtkTreeIter  *iter)
 {
   ExoIconChooserModel *model = EXO_ICON_CHOOSER_MODEL (tree_model);
-  gint                 index;
+  gint                 idx;
 
   _exo_return_val_if_fail (EXO_IS_ICON_CHOOSER_MODEL (model), NULL);
   _exo_return_val_if_fail (iter->stamp == model->stamp, NULL);
 
   /* lookup the list item in the icon list */
-  index = g_list_position (model->items, iter->user_data);
-  if (G_LIKELY (index >= 0))
-    return gtk_tree_path_new_from_indices (index, -1);
+  idx = g_list_position (model->items, iter->user_data);
+  if (G_LIKELY (idx >= 0))
+    return gtk_tree_path_new_from_indices (idx, -1);
 
   return NULL;
 }
@@ -373,7 +350,7 @@ exo_icon_chooser_model_iter_children (GtkTreeModel *tree_model,
       iter->user_data = model->items;
       return TRUE;
     }
-  
+
   return FALSE;
 }
 
@@ -467,7 +444,7 @@ exo_icon_chooser_model_icon_theme_changed (GtkIconTheme        *icon_theme,
   for (itp = items; itp != NULL; itp = itp->next)
     {
       /* allocate a model item for the icon... */
-      item = _exo_slice_new (ExoIconChooserModelItem);
+      item = g_slice_new (ExoIconChooserModelItem);
       item->context = EXO_ICON_CHOOSER_CONTEXT_OTHER;
       item->icon_name = itp->data;
       item->display_name = NULL;
@@ -545,7 +522,7 @@ exo_icon_chooser_model_item_free (ExoIconChooserModelItem *item)
   g_free (item->icon_name);
 
   /* release the item */
-  _exo_slice_free (ExoIconChooserModelItem, item);
+  g_slice_free (ExoIconChooserModelItem, item);
 }
 
 
@@ -558,7 +535,7 @@ exo_icon_chooser_model_item_free (ExoIconChooserModelItem *item)
  * caller is responsible to free the returned object using g_object_unref()
  * when no longer needed.
  *
- * Return value: an #ExoIconChooserModel for the @widget.
+ * Returns: an #ExoIconChooserModel for the @widget.
  *
  * Since: 0.3.1.9
  **/
@@ -586,7 +563,7 @@ _exo_icon_chooser_model_get_for_widget (GtkWidget *widget)
  * caller is responsible to free the returned object using g_object_unref()
  * when no longer needed.
  *
- * Return value: an #ExoIconChooserModel for the @icon_theme.
+ * Returns: an #ExoIconChooserModel for the @icon_theme.
  *
  * Since: 0.3.1.9
  **/
@@ -630,7 +607,7 @@ _exo_icon_chooser_model_get_for_icon_theme (GtkIconTheme *icon_theme)
  * Looks up the #GtkTreeIter for the @icon_name in the @model and returns %TRUE if the
  * @icon_name was found, %FALSE otherwise.
  *
- * Return value: %TRUE if the iterator for @icon_name was found, %FALSE otherwise.
+ * Returns: %TRUE if the iterator for @icon_name was found, %FALSE otherwise.
  *
  * Since: 0.3.1.9
  **/
