@@ -1,4 +1,4 @@
-/* $Id: exo-mount-point.c 25931 2007-07-20 20:18:08Z benny $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2005-2007 Benedikt Meurer <benny@xfce.org>.
  *
@@ -72,6 +72,19 @@
 #include <exo/exo-string.h>
 #include <exo/exo-alias.h>
 
+/**
+ * SECTION: exo-mount-point
+ * @title: Mount Points
+ * @short_description: Functions to query active and configured mount points
+ * @include: exo/exo.h
+ *
+ * This module provides functions to query active and configured mount
+ * points from the system. This is commonly required in file and volume
+ * management, and hence it was added to the library. For example,
+ * <command>exo-mount</command>, <command>Thunar</command> and
+ * <command>thunar-volman</command> make use of this.
+ **/
+
 
 
 /* define _PATH_FSTAB if undefined */
@@ -175,7 +188,7 @@ match_device_by_path:
     }
 
   /* allocate an ExoMountPoint, we matched */
-  mount_point = _exo_slice_new (ExoMountPoint);
+  mount_point = g_slice_new (ExoMountPoint);
   mount_point->flags = real_read_only ? EXO_MOUNT_POINT_READ_ONLY : 0;
   mount_point->device = g_strdup (real_device);
   mount_point->folder = g_strdup (real_folder);
@@ -253,32 +266,6 @@ exo_mount_point_list_match_active (ExoMountPointMatchMask mask,
 
   /* close the file handle */
   fclose (fp);
-#elif defined(HAVE_GETFSSTAT) /* FreeBSD, OpenBSD, DragonFly, older NetBSD */
-  struct statfs *mntbuf = NULL;
-  glong          bufsize = 0;
-  gint           mntsize;
-  gint           n;
-
-  /* determine the number of active mount points */
-  mntsize = getfsstat (NULL, 0, MNT_NOWAIT);
-  if (G_LIKELY (mntsize > 0))
-    {
-      /* allocate a new buffer */
-      bufsize = (mntsize + 4) * sizeof (*mntbuf);
-      mntbuf = (struct statfs *) malloc (bufsize);
-
-      /* determine the mount point for the device file */
-      mntsize = getfsstat (mntbuf, bufsize, MNT_NOWAIT);
-      for (n = 0; n < mntsize; ++n)
-        {
-          /* check if we have a match here */
-          exo_mount_point_add_if_matches (mask, device, folder, fstype, mntbuf[n].f_mntfromname, mntbuf[n].f_mntonname,
-                                          mntbuf[n].f_fstypename, ((mntbuf[n].f_flags & MNT_RDONLY) != 0), &mount_points);
-        }
-
-      /* release the buffer */
-      free (mntbuf);
-    }
 #elif defined(HAVE_GETVFSSTAT) /* Newer NetBSD */
   struct statvfs *mntbuf = NULL;
   glong           bufsize = 0;
@@ -306,6 +293,32 @@ exo_mount_point_list_match_active (ExoMountPointMatchMask mask,
                                           &mount_points);
         }
 
+      /* release the buffer */
+      free (mntbuf);
+    }
+#elif defined(HAVE_GETFSSTAT) /* FreeBSD, OpenBSD, DragonFly, older NetBSD */
+  struct statfs *mntbuf = NULL;
+  glong          bufsize = 0;
+  gint           mntsize;
+  gint           n;
+
+  /* determine the number of active mount points */
+  mntsize = getfsstat (NULL, 0, MNT_NOWAIT);
+  if (G_LIKELY (mntsize > 0))
+    {
+      /* allocate a new buffer */
+      bufsize = (mntsize + 4) * sizeof (*mntbuf);
+      mntbuf = (struct statfs *) malloc (bufsize);
+
+      /* determine the mount point for the device file */
+      mntsize = getfsstat (mntbuf, bufsize, MNT_NOWAIT);
+      for (n = 0; n < mntsize; ++n)
+        {
+          /* check if we have a match here */
+          exo_mount_point_add_if_matches (mask, device, folder, fstype, mntbuf[n].f_mntfromname, mntbuf[n].f_mntonname,
+                                          mntbuf[n].f_fstypename, ((mntbuf[n].f_flags & MNT_RDONLY) != 0), &mount_points);
+        }
+
       /* release the buffer */
       free (mntbuf);
     }
@@ -458,7 +471,7 @@ exo_mount_point_get_type (void)
  * point using exo_mount_point_free() when no longer
  * needed.
  *
- * Return value: a copy of the specified @mount_point.
+ * Returns: a copy of the specified @mount_point.
  *
  * Since: 0.3.1.13
  **/
@@ -469,7 +482,7 @@ exo_mount_point_dup (const ExoMountPoint *mount_point)
 
   if (G_LIKELY (mount_point != NULL))
     {
-      duplicate = _exo_slice_new (ExoMountPoint);
+      duplicate = g_slice_new (ExoMountPoint);
       duplicate->flags = mount_point->flags;
       duplicate->device = g_strdup (mount_point->device);
       duplicate->folder = g_strdup (mount_point->folder);
@@ -502,7 +515,7 @@ exo_mount_point_free (ExoMountPoint *mount_point)
       g_free (mount_point->device);
       g_free (mount_point->folder);
       g_free (mount_point->fstype);
-      _exo_slice_free (ExoMountPoint, mount_point);
+      g_slice_free (ExoMountPoint, mount_point);
     }
 }
 
@@ -534,7 +547,7 @@ exo_mount_point_free (ExoMountPoint *mount_point)
  * </programlisting></informalexample>
  * when no longer needed.
  *
- * Return value: the list of matching #ExoMountPoint<!---->s.
+ * Returns: the list of matching #ExoMountPoint<!---->s.
  *
  * Since: 0.3.1.13
  **/
@@ -552,7 +565,7 @@ exo_mount_point_list_matched (ExoMountPointMatchMask mask,
   g_return_val_if_fail ((mask & EXO_MOUNT_POINT_MATCH_FSTYPE) == 0 || fstype != NULL, NULL);
   g_return_val_if_fail (error == NULL || *error == NULL, NULL);
 
-#if defined(HAVE_GETFSSTAT) && !defined(HAVE_GETMNTENT) && !defined(HAVE_SETMNTENT) 
+#if defined(HAVE_GETFSSTAT) && !defined(HAVE_GETMNTENT) && !defined(HAVE_SETMNTENT)
   /* getfsstat(2) is really thread-safe, so we can skip locking there */
   if ((mask & EXO_MOUNT_POINT_MATCH_CONFIGURED) == EXO_MOUNT_POINT_MATCH_CONFIGURED)
 #endif
@@ -566,7 +579,7 @@ exo_mount_point_list_matched (ExoMountPointMatchMask mask,
                ? exo_mount_point_list_match_active (mask, device, folder, fstype, error)
                : exo_mount_point_list_match_configured (mask, device, folder, fstype, error);
 
-#if defined(HAVE_GETFSSTAT) && !defined(HAVE_GETMNTENT) && !defined(HAVE_SETMNTENT) 
+#if defined(HAVE_GETFSSTAT) && !defined(HAVE_GETMNTENT) && !defined(HAVE_SETMNTENT)
   /* getfsstat(2) is really thread-safe, so we can skip locking there */
   if ((mask & EXO_MOUNT_POINT_MATCH_CONFIGURED) == EXO_MOUNT_POINT_MATCH_CONFIGURED)
 #endif
