@@ -30,10 +30,23 @@
 #ifdef HAVE_STRING_H
 #include <string.h>
 #endif
+#ifdef HAVE_TIME_H
+#include <time.h>
+#endif
 
 #include <exo/exo-string.h>
 #include <exo/exo-alias.h>
 
+/**
+ * SECTION: exo-string
+ * @title: String Utility Functions
+ * @short_description: Various string-related functions
+ * @include: exo/exo.h
+ *
+ * This section describes a number of utility functions for
+ * manipulating strings.
+ **/
+
 
 
 /**
@@ -43,9 +56,8 @@
  * Returns a copy of @text with all mnemonic underscores
  * stripped off.
  *
- * Return value: A copy of @text without underscores. The
- *               returned string must be freed when no
- *               longer required.
+ * Returns: A copy of @text without underscores. The returned string
+ *          must be freed when no longer required.
  **/
 gchar*
 exo_str_elide_underscores (const gchar *text)
@@ -56,7 +68,7 @@ exo_str_elide_underscores (const gchar *text)
   gchar       *t;
 
   g_return_val_if_fail (text != NULL, NULL);
-  
+
   result = g_malloc (strlen (text) + 1);
 
   for (s = text, t = result; *s != '\0'; ++s)
@@ -87,16 +99,14 @@ exo_str_elide_underscores (const gchar *text)
  *
  * You should always prefer this function over strcmp().
  *
- * Return value: %TRUE if @a equals @b, else %FALSE.
+ * Returns: %TRUE if @a equals @b, else %FALSE.
  **/
 gboolean
 exo_str_is_equal (const gchar *a,
                   const gchar *b)
 {
-  if (a == NULL && b == NULL)
-    return TRUE;
-  else if (a == NULL || b == NULL)
-    return FALSE;
+  if (a == NULL || b == NULL)
+    return (a == b);
 
   while (*a == *b++)
     if (*a++ == '\0')
@@ -120,11 +130,12 @@ exo_str_is_equal (const gchar *a,
  * g_free() when no longer needed.
  *
  * Note that @pattern and @replacement don't need to be of the
- * same size.
+ * same size. If @replacement is %NULL, the pattern will be
+ * removed from the string.
  *
- * Return value: a newly allocated copy of @str where all
- *               occurances of @pattern are replaced with
- *               @replacement.
+ * Returns: a newly allocated copy of @str where all occurances of
+ *          @pattern are replaced with @replacement. Or %NULL if
+ *          @str and/or @pattern is %NULL.
  *
  * Since: 0.3.1.1
  **/
@@ -136,16 +147,14 @@ exo_str_replace (const gchar *str,
   const gchar *s, *p;
   GString     *result;
 
-  g_return_val_if_fail (str != NULL, NULL);
-  g_return_val_if_fail (pattern != NULL, NULL);
-  g_return_val_if_fail (replacement != NULL, NULL);
-
-  /* empty patterns are kinda useless, so we just return a copy of str */
-  if (G_UNLIKELY (*pattern == '\0'))
+  /* an empty string or pattern is useless, so just
+   * return a copy of str */
+  if (G_UNLIKELY (exo_str_is_empty (str)
+      || exo_str_is_empty (pattern)))
     return g_strdup (str);
 
   /* allocate the result string */
-  result = g_string_new (NULL);
+  result = g_string_sized_new (strlen (str));
 
   /* process the input string */
   while (*str != '\0')
@@ -157,10 +166,11 @@ exo_str_replace (const gchar *str,
             if (*p == '\0' || *s == '\0')
               break;
 
-          /* check if the pattern matches */
+          /* check if the pattern fully matched */
           if (G_LIKELY (*p == '\0'))
             {
-              g_string_append (result, replacement);
+              if (G_LIKELY (!exo_str_is_empty (replacement)))
+                g_string_append (result, replacement);
               str = s;
               continue;
             }
@@ -195,7 +205,7 @@ exo_str_replace (const gchar *str,
  * warning, so it's easy to notice use of the extensions without
  * testing with multiple versions of the library.
  *
- * Return value: a newly allocated string containing the formatted date/time.
+ * Returns: a newly allocated string containing the formatted date/time.
  *
  * Since: 0.3.3
  **/
@@ -226,7 +236,7 @@ exo_strdup_strftime (const gchar     *format,
   converted = g_locale_from_utf8 (format, -1, NULL, NULL, NULL);
   if (G_UNLIKELY (converted == NULL))
     return NULL;
-  
+
   /* start processing the format */
   string = g_string_new ("");
   remainder = converted;
@@ -287,8 +297,8 @@ exo_strdup_strftime (const gchar     *format,
               g_warning ("Unfinished %%%c modifier passed to exo_strdup_strftime", modifier);
               break;
             }
-        } 
-      
+        }
+
       if (strchr (C_STANDARD_STRFTIME_CHARACTERS, *remainder) == NULL)
         g_warning ("exo_strdup_strftime does not support non-standard escape code %%%c", *remainder);
 
@@ -342,7 +352,7 @@ exo_strdup_strftime (const gchar     *format,
       /* add this piece */
       g_string_append (string, piece);
     }
-  
+
   /* Convert the string back into UTF-8 */
   result = g_locale_to_utf8 (string->str, -1, NULL, NULL, NULL);
 
@@ -358,29 +368,35 @@ exo_strdup_strftime (const gchar     *format,
 /**
  * exo_strndupv:
  * @strv  : String vector to duplicate.
- * @num   : Number of strings in @strv to
- *          duplicate.
+ * @num   : Number of strings in @strv to duplicate.
  *
- * Creates a new string vector containing the
- * first @n elements of @strv.
+ * Creates a new string vector containing the first @n elements
+ * of @strv. If called on a %NULL value or @num is 0, exo_strndupv()
+ * simply returns %NULL.
  *
- * Return value: The new string vector. Should be
- *               freed using g_strfreev() when no
- *               longer needed.
+ * Returns: A new NULL-terminated array of strings or %NULL.
+ *          Should be freed using g_strfreev() when no longer needed.
  **/
 gchar**
 exo_strndupv (gchar **strv,
-              gint    num)
+              guint   num)
 {
   gchar **result;
+  guint   i;
 
-  g_return_val_if_fail (strv != NULL, NULL);
-  g_return_val_if_fail (num >= 0, NULL);
+  /* return null when there is nothing to copy */
+  if (G_UNLIKELY (strv == NULL || num == 0))
+    return NULL;
 
+  /* duplicate the first @num string */
   result = g_new (gchar *, num + 1);
-  result[num--] = NULL;
-  for (; num >= 0; --num)
-    result[num] = g_strdup (strv[num]);
+  for (i = 0; strv[i] != NULL && i < num; i++)
+    result[i] = g_strdup (strv[i]);
+  result[i] = NULL;
+
+  /* resize the string if we allocated too much space */
+  if (G_UNLIKELY (num > i))
+    result = g_renew (gchar *, result, i + 1);
 
   return result;
 }
@@ -388,51 +404,30 @@ exo_strndupv (gchar **strv,
 
 
 /**
- * exo_intern_string:
- * @string: a string
- * 
- * Returns a canonical representation for @string. Interned strings can
- * be compared for equality by comparing the pointers, instead of using strcmp()
- * or exo_str_is_equal(). exo_intern_string() takes a copy of the @string for its
- * internal usage, so @string does not need to be static.
- * 
- * Return value: a canonical representation for the string
+ * exo_str_looks_like_an_uri:
+ * @str : an input string.
  *
- * Since: 0.3.1.1
- */
-G_CONST_RETURN gchar*
-exo_intern_string (const gchar *string)
-{
-#if GLIB_CHECK_VERSION(2,9,0)
-  return g_intern_string (string);
-#else
-  return (string != NULL) ? g_quark_to_string (g_quark_from_string (string)) : NULL;
-#endif
-}
-
-
-
-/**
- * exo_intern_static_string:
- * @string: a static string
- * 
- * Returns a canonical representation for @string. Interned strings can
- * be compared for equality by comparing the pointers, instead of using strcmp()
- * or exo_str_is_equal(). exo_intern_static_string() does not copy the string,
- * therefore @string must not be freed or modified. 
- * 
- * Return value: a canonical representation for the string
+ * Returns %TRUE if the @string looks like an URI
+ * according to RFC 2396, %FALSE otherwise.
  *
- * Since: 0.3.1.1
- */
-G_CONST_RETURN gchar*
-exo_intern_static_string (const gchar *string)
+ * Since: 0.5.0
+ **/
+gboolean
+exo_str_looks_like_an_uri (const gchar *str)
 {
-#if GLIB_CHECK_VERSION(2,9,0)
-  return g_intern_static_string (string);
-#else
-  return (string != NULL) ? g_quark_to_string (g_quark_from_static_string (string)) : NULL;
-#endif
+  const gchar *s = str;
+
+  /* <scheme> starts with an alpha character */
+  if (g_ascii_isalpha (*s))
+    {
+      /* <scheme> continues with (alpha | digit | "+" | "-" | ".")* */
+      for (++s; g_ascii_isalnum (*s) || *s == '+' || *s == '-' || *s == '.'; ++s);
+
+      /* <scheme> must be followed by ":" */
+      return (*s == ':');
+    }
+
+  return FALSE;
 }
 
 
