@@ -1,4 +1,4 @@
-/* $Id: exo-toolbars-private.c 18995 2005-12-05 16:46:54Z benny $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2004 os-cillation e.K.
  * Copyright (c) 2003 Marco Pesenti Gritti
@@ -68,16 +68,15 @@ new_pixbuf_from_widget (GtkWidget *widget)
 
   icon_width = DEFAULT_ICON_WIDTH;
 
-  if (!gtk_icon_size_lookup_for_settings (gtk_settings_get_default (), 
-					  GTK_ICON_SIZE_LARGE_TOOLBAR,
-					  NULL, 
-					  &icon_height))
+  if (!gtk_icon_size_lookup_for_settings (gtk_settings_get_default (),
+                                          GTK_ICON_SIZE_LARGE_TOOLBAR,
+                                          NULL, &icon_height))
     {
       icon_height = DEFAULT_ICON_HEIGHT;
     }
 
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-  
+
   gtk_container_add (GTK_CONTAINER (window), widget);
   gtk_widget_realize (window);
   gtk_widget_show (widget);
@@ -99,7 +98,7 @@ new_pixbuf_from_widget (GtkWidget *widget)
   allocation.height = icon_height;
   gtk_widget_size_allocate (window, &allocation);
   gtk_widget_size_request (window, &requisition);
-  
+
   /* Create a pixmap */
   pixmap = gdk_pixmap_new (GDK_DRAWABLE (window->window), icon_width, icon_height, -1);
   gdk_drawable_set_colormap (GDK_DRAWABLE (pixmap), gtk_widget_get_colormap (window));
@@ -108,10 +107,10 @@ new_pixbuf_from_widget (GtkWidget *widget)
   gtk_widget_ensure_style (window);
   g_assert (window->style);
   g_assert (window->style->font_desc);
-  
+
   fake_expose_widget (window, pixmap);
   fake_expose_widget (widget, pixmap);
-  
+
   pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, icon_width, icon_height);
   gdk_pixbuf_get_from_drawable (pixbuf, pixmap, NULL, 0, 0, 0, 0, icon_width, icon_height);
 
@@ -147,7 +146,7 @@ style_set (GtkWidget *image)
  * Creates a new #GdkPixbuf with the picture
  * of a vertical separator.
  *
- * Return value : A #GdkPixbuf.
+ * Returns: A #GdkPixbuf.
  **/
 GdkPixbuf*
 _exo_toolbars_new_separator_pixbuf (void)
@@ -170,7 +169,7 @@ _exo_toolbars_new_separator_pixbuf (void)
  * Creates a #GtkImage with the picture of a
  * vertical separator in it.
  *
- * Return value : A #GtkImage.
+ * Returns: A #GtkImage.
  **/
 GtkWidget*
 _exo_toolbars_new_separator_image (void)
@@ -192,8 +191,7 @@ _exo_toolbars_new_separator_image (void)
  * @ui_manager  : A #GtkUIManager.
  * @name        : The name of an action in @ui_manager.
  *
- * Return value : The last #GtkAction named @name in @ui_manager
- *                or %NULL.
+ * Returns: The last #GtkAction named @name in @ui_manager or %NULL.
  **/
 GtkAction*
 _exo_toolbars_find_action (GtkUIManager *ui_manager,
@@ -222,9 +220,9 @@ _exo_toolbars_find_action (GtkUIManager *ui_manager,
 #pragma align 4 (drag_cursor_data)
 #endif
 #ifdef __GNUC__
-static const guint8 drag_cursor_data[] __attribute__ ((__aligned__ (4))) = 
+static const guint8 drag_cursor_data[] __attribute__ ((__aligned__ (4))) =
 #else
-static const guint8 drag_cursor_data[] = 
+static const guint8 drag_cursor_data[] =
 #endif
 { ""
   /* Pixbuf magic (0x47646b50) */
