@@ -40,13 +40,22 @@
 #include <exo/exo-toolbars-view.h>
 #include <exo/exo-alias.h>
 
+/**
+ * SECTION: exo-toolbars-view
+ * @title: ExoToolbarsView
+ * @short_description: Widget for displaying toolbars
+ * @include: exo/exo.h
+ * @see_also: #ExoToolbarsEditor, #ExoToolbarsEditorDialog, #ExoToolbarsModel
+ *
+ * A widget that displays toolbars as described in a #ExoToolbarsModel object.
+ **/
+
 
 
 #define MIN_TOOLBAR_HEIGHT  20
 
-
-
-#define EXO_TOOLBARS_VIEW_GET_PRIVATE(obj)  (G_TYPE_INSTANCE_GET_PRIVATE ((obj), EXO_TYPE_TOOLBARS_VIEW, ExoToolbarsViewPrivate))
+#define EXO_TOOLBARS_VIEW_GET_PRIVATE(obj)  (G_TYPE_INSTANCE_GET_PRIVATE ((obj), \
+   EXO_TYPE_TOOLBARS_VIEW, ExoToolbarsViewPrivate))
 
 
 
@@ -67,8 +76,6 @@ enum
 
 
 
-static void         exo_toolbars_view_class_init            (ExoToolbarsViewClass *klass);
-static void         exo_toolbars_view_init                  (ExoToolbarsView      *view);
 static void         exo_toolbars_view_finalize              (GObject              *object);
 static void         exo_toolbars_view_get_property          (GObject              *object,
                                                              guint                 prop_id,
@@ -92,7 +99,7 @@ static void         exo_toolbars_view_drag_data_get             (GtkWidget
                                                                  GdkDragContext       *context,
                                                                  GtkSelectionData     *selection_data,
                                                                  guint                 info,
-                                                                 guint32               time,
+                                                                 guint32               drag_time,
                                                                  ExoToolbarsView      *view);
 static GtkWidget   *exo_toolbars_view_create_item_from_action   (ExoToolbarsView      *view,
                                                                  const gchar          *action_name,
@@ -110,7 +117,7 @@ static void         exo_toolbars_view_drag_data_received        (GtkWidget
                                                                  gint                  y,
                                                                  GtkSelectionData     *selection_data,
                                                                  guint                 info,
-                                                                 guint                 time,
+                                                                 guint                 drag_time,
                                                                  ExoToolbarsView      *view);
 static void         exo_toolbars_view_context_menu              (GtkWidget            *toolbar,
                                                                  gint                  x,
@@ -122,17 +129,17 @@ static gboolean     exo_toolbars_view_drag_drop                 (GtkWidget
                                                                  GdkDragContext       *context,
                                                                  gint                  x,
                                                                  gint                  y,
-                                                                 guint                 time,
+                                                                 guint                 drag_time,
                                                                  ExoToolbarsView      *view);
 static gboolean     exo_toolbars_view_drag_motion               (GtkWidget            *toolbar,
                                                                  GdkDragContext       *context,
                                                                  gint                  x,
                                                                  gint                  y,
-                                                                 guint                 time,
+                                                                 guint                 drag_time,
                                                                  ExoToolbarsView      *view);
 static void         exo_toolbars_view_drag_leave                (GtkWidget            *toolbar,
                                                                  GdkDragContext       *context,
-                                                                 guint                 time,
+                                                                 guint                 drag_time,
                                                                  ExoToolbarsView      *view);
 static GtkWidget   *exo_toolbars_view_create_dock               (ExoToolbarsView      *view);
 static void         exo_toolbars_view_toolbar_added             (ExoToolbarsModel     *model,
@@ -177,28 +184,11 @@ static const GtkTargetEntry dst_targets[] =
   { EXO_TOOLBARS_ITEM_TYPE, GTK_TARGET_SAME_APP, 0 },
 };
 
-static GObjectClass *exo_toolbars_view_parent_class;
-static guint         toolbars_view_signals[LAST_SIGNAL];
+static guint  toolbars_view_signals[LAST_SIGNAL];
 
 
 
-GType
-exo_toolbars_view_get_type (void)
-{
-  static GType type = G_TYPE_INVALID;
-
-  if (G_UNLIKELY (type == G_TYPE_INVALID))
-    {
-      type = _exo_g_type_register_simple (GTK_TYPE_VBOX,
-                                          "ExoToolbarsView",
-                                          sizeof (ExoToolbarsViewClass),
-                                          exo_toolbars_view_class_init,
-                                          sizeof (ExoToolbarsView),
-                                          exo_toolbars_view_init);
-    }
-
-  return type;
-}
+G_DEFINE_TYPE (ExoToolbarsView, exo_toolbars_view, GTK_TYPE_VBOX)
 
 
 
@@ -212,8 +202,6 @@ exo_toolbars_view_class_init (ExoToolbarsViewClass *klass)
 
   g_type_class_add_private (klass, sizeof (ExoToolbarsViewPrivate));
 
-  exo_toolbars_view_parent_class = g_type_class_peek_parent (klass);
-
   gobject_class = G_OBJECT_CLASS (klass);
   gobject_class->finalize = exo_toolbars_view_finalize;
   gobject_class->get_property = exo_toolbars_view_get_property;
@@ -480,7 +468,7 @@ exo_toolbars_view_drag_data_get (GtkWidget        *item,
                                  GdkDragContext   *context,
                                  GtkSelectionData *selection_data,
                                  guint             info,
-                                 guint32           time,
+                                 guint32           drag_time,
                                  ExoToolbarsView  *view)
 {
   const gchar *type;
@@ -528,8 +516,11 @@ set_item_drag_source (ExoToolbarsModel  *model,
       id = "separator";
 
       pixbuf = _exo_toolbars_new_separator_pixbuf ();
-      gtk_drag_source_set_icon_pixbuf (item, pixbuf);
-      g_object_unref (G_OBJECT (pixbuf));
+      if (G_LIKELY (pixbuf != NULL))
+        {
+          gtk_drag_source_set_icon_pixbuf (item, pixbuf);
+          g_object_unref (G_OBJECT (pixbuf));
+        }
     }
   else
     {
@@ -540,8 +531,11 @@ set_item_drag_source (ExoToolbarsModel  *model,
         stock_id = g_strdup (GTK_STOCK_DND);
 
       pixbuf = gtk_widget_render_icon (item, stock_id, GTK_ICON_SIZE_LARGE_TOOLBAR, NULL);
-      gtk_drag_source_set_icon_pixbuf (item, pixbuf);
-      g_object_unref (G_OBJECT (pixbuf));
+      if (G_LIKELY (pixbuf != NULL))
+        {
+          gtk_drag_source_set_icon_pixbuf (item, pixbuf);
+          g_object_unref (G_OBJECT (pixbuf));
+        }
 
       g_free (stock_id);
     }
@@ -643,7 +637,7 @@ exo_toolbars_view_drag_data_received (GtkWidget         *toolbar,
                                       gint               y,
                                       GtkSelectionData  *selection_data,
                                       guint              info,
-                                      guint              time,
+                                      guint              drag_time,
                                       ExoToolbarsView   *view)
 {
   GdkAtom target;
@@ -682,7 +676,7 @@ exo_toolbars_view_drag_data_received (GtkWidget         *toolbar,
       else
         exo_toolbars_model_add_item (view->priv->model, toolbar_position, item_position, id, type);
 
-      gtk_drag_finish (context, TRUE, context->action == GDK_ACTION_MOVE, time);
+      gtk_drag_finish (context, TRUE, context->action == GDK_ACTION_MOVE, drag_time);
     }
 
   g_free (type);
@@ -741,7 +735,7 @@ exo_toolbars_view_context_menu (GtkWidget       *toolbar,
                                 ExoToolbarsView *view)
 {
   ExoToolbarsModelFlags flags;
-  GtkToolbarStyle       style = -1;
+  gint                  style = -1;
   GtkWidget            *submenu;
   GtkWidget            *menu;
   GtkWidget            *item;
@@ -856,7 +850,7 @@ exo_toolbars_view_drag_drop (GtkWidget        *widget,
                              GdkDragContext   *context,
                              gint              x,
                              gint              y,
-                             guint             time,
+                             guint             drag_time,
                              ExoToolbarsView  *view)
 {
   GdkAtom target;
@@ -864,7 +858,7 @@ exo_toolbars_view_drag_drop (GtkWidget        *widget,
   target = gtk_drag_dest_find_target (widget, context, NULL);
   if (G_LIKELY (target != GDK_NONE))
     {
-      gtk_drag_get_data (widget, context, target, time);
+      gtk_drag_get_data (widget, context, target, drag_time);
       return TRUE;
     }
 
@@ -880,7 +874,7 @@ exo_toolbars_view_drag_motion (GtkWidget        *toolbar,
                                GdkDragContext   *context,
                                gint              x,
                                gint              y,
-                               guint             time,
+                               guint             drag_time,
                                ExoToolbarsView  *view)
 {
   ExoToolbarsModelFlags flags;
@@ -888,7 +882,7 @@ exo_toolbars_view_drag_motion (GtkWidget        *toolbar,
   gboolean              is_item;
   GdkAtom               target;
   gint                  toolbar_position;
-  gint                  index;
+  gint                  idx;
 
   source = gtk_drag_get_source_widget (context);
   if (G_LIKELY (source != NULL))
@@ -902,7 +896,7 @@ exo_toolbars_view_drag_motion (GtkWidget        *toolbar,
 
       if ((flags & EXO_TOOLBARS_MODEL_ACCEPT_ITEMS_ONLY) != 0 && !is_item)
         {
-          gdk_drag_status (context, 0, time);
+          gdk_drag_status (context, 0, drag_time);
           return FALSE;
         }
 
@@ -913,7 +907,7 @@ exo_toolbars_view_drag_motion (GtkWidget        *toolbar,
   target = gtk_drag_dest_find_target (toolbar, context, NULL);
   if (G_UNLIKELY (target == GDK_NONE))
     {
-      gdk_drag_status (context, 0, time);
+      gdk_drag_status (context, 0, drag_time);
       return FALSE;
     }
 
@@ -929,18 +923,18 @@ exo_toolbars_view_drag_motion (GtkWidget        *toolbar,
       view->priv->target_toolbar = toolbar;
       view->priv->pending = TRUE;
 
-      gtk_drag_get_data (toolbar, context, target, time);
+      gtk_drag_get_data (toolbar, context, target, drag_time);
     }
 
   if (view->priv->dragged_item != NULL && view->priv->editing)
     {
-      index = gtk_toolbar_get_drop_index (GTK_TOOLBAR (toolbar), x, y);
+      idx = gtk_toolbar_get_drop_index (GTK_TOOLBAR (toolbar), x, y);
       gtk_toolbar_set_drop_highlight_item (GTK_TOOLBAR (toolbar),
                                            GTK_TOOL_ITEM (view->priv->dragged_item),
-                                           index);
+                                           idx);
     }
 
-  gdk_drag_status (context, context->suggested_action, time);
+  gdk_drag_status (context, context->suggested_action, drag_time);
 
   return TRUE;
 }
@@ -950,7 +944,7 @@ exo_toolbars_view_drag_motion (GtkWidget        *toolbar,
 static void
 exo_toolbars_view_drag_leave (GtkWidget       *toolbar,
                               GdkDragContext  *context,
-                              guint            time,
+                              guint            drag_time,
                               ExoToolbarsView *view)
 {
   if (view->priv->target_toolbar == toolbar)
@@ -1117,6 +1111,9 @@ exo_toolbars_view_construct (ExoToolbarsView *view)
   if (view->priv->model == NULL || view->priv->ui_manager == NULL)
     return;
 
+  /* ensure there are no pending updates before getting the widgets */
+  gtk_ui_manager_ensure_update (view->priv->ui_manager);
+
   n_toolbars = exo_toolbars_model_n_toolbars (view->priv->model);
   for (i = 0; i < n_toolbars; ++i)
     {
@@ -1179,7 +1176,7 @@ exo_toolbars_view_deconstruct (ExoToolbarsView *view)
  *
  * Creates a new #ExoToolbarsView.
  *
- * Return value: A newly created #ExoToolbarsView.
+ * Returns: A newly created #ExoToolbarsView.
  **/
 GtkWidget*
 exo_toolbars_view_new (GtkUIManager *ui_manager)
@@ -1201,7 +1198,7 @@ exo_toolbars_view_new (GtkUIManager *ui_manager)
  * Creates a new #ExoToolbarsView and associates it with
  * @model.
  *
- * Return value: A newly created #ExoToolbarsView.
+ * Returns: A newly created #ExoToolbarsView.
  **/
 GtkWidget*
 exo_toolbars_view_new_with_model (GtkUIManager      *ui_manager,
@@ -1222,7 +1219,9 @@ exo_toolbars_view_new_with_model (GtkUIManager      *ui_manager,
  * exo_toolbars_view_get_editing:
  * @view  : An #ExoToolbarsView.
  *
- * Return value: %TRUE if @view is currently being edited, else %FALSE.
+ * Gets wether @view is currently being edited.
+ *
+ * Returns: %TRUE if @view is currently being edited, else %FALSE.
  **/
 gboolean
 exo_toolbars_view_get_editing (ExoToolbarsView *view)
@@ -1302,7 +1301,7 @@ exo_toolbars_view_set_editing (ExoToolbarsView *view,
  * Returns the #ExoToolbarsModel currently associated with
  * @view or %NULL if @view has no model.
  *
- * Return value: The #ExoToolbarsModel associated with @view.
+ * Returns: The #ExoToolbarsModel associated with @view.
  **/
 ExoToolbarsModel*
 exo_toolbars_view_get_model (ExoToolbarsView *view)
@@ -1317,6 +1316,9 @@ exo_toolbars_view_get_model (ExoToolbarsView *view)
  * exo_toolbars_view_set_model:
  * @view  : An #ExoToolbarsView.
  * @model : An #ExoToolbarsModel or %NULL.
+ *
+ * Set the #ExoToolbarsModel currently associated with
+ * @view or %NULL to disconnect from the active model.
  **/
 void
 exo_toolbars_view_set_model (ExoToolbarsView  *view,
@@ -1380,8 +1382,10 @@ exo_toolbars_view_set_model (ExoToolbarsView  *view,
  * exo_toolbars_view_get_ui_manager:
  * @view        : An #ExoToolbarsView.
  *
- * Return value: The #GtkUIManager associated with @view or
- *               %NULL.
+ * Returns the #GtkUIManager currently associated with @view or %NULL is
+ * no ui-manager has been set.
+ *
+ * Returns: The #GtkUIManager associated with @view or %NULL.
  **/
 GtkUIManager*
 exo_toolbars_view_get_ui_manager (ExoToolbarsView *view)
@@ -1396,6 +1400,9 @@ exo_toolbars_view_get_ui_manager (ExoToolbarsView *view)
  * exo_toolbars_view_set_ui_manager:
  * @view        : An #ExoToolbarsView.
  * @ui_manager  : A #GtkUIManager or %NULL.
+ *
+ * Set the #GtkUIManager currently associated with @view or %NULL
+ * to disconnect from the current ui-manager.
  **/
 void
 exo_toolbars_view_set_ui_manager (ExoToolbarsView *view,
