@@ -1,4 +1,4 @@
-/* $Id: exo-wrap-table.c 22884 2006-08-26 12:40:43Z benny $ */
+/* $Id$ */
 /*-
  * Copyright (c) 2000      Ramiro Estrugo <ramiro@eazel.com>
  * Copyright (c) 2005-2006 Benedikt Meurer <benny@xfce.org>
@@ -29,9 +29,23 @@
 #include <exo/exo-wrap-table.h>
 #include <exo/exo-alias.h>
 
+/**
+ * SECTION: exo-wrap-table
+ * @title: ExoWrapTable
+ * @short_description: A container widget with automatic child layouting
+ * @include: exo/exo.h
+ *
+ * The #ExoWrapTable class layouts its children automatically
+ * according to the available width allocated to the container
+ * class.
+ *
+ * Since: 0.3.1
+ **/
 
 
-#define EXO_WRAP_TABLE_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), EXO_TYPE_WRAP_TABLE, ExoWrapTablePrivate))
+
+#define EXO_WRAP_TABLE_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), \
+    EXO_TYPE_WRAP_TABLE, ExoWrapTablePrivate))
 
 
 
@@ -46,8 +60,6 @@ enum
 
 
 
-static void exo_wrap_table_class_init         (ExoWrapTableClass  *klass);
-static void exo_wrap_table_init               (ExoWrapTable       *table);
 static void exo_wrap_table_get_property       (GObject            *object,
                                                guint               prop_id,
                                                GValue             *value,
@@ -94,27 +106,7 @@ struct _ExoWrapTablePrivate
 
 
 
-static GObjectClass *exo_wrap_table_parent_class;
-
-
-
-GType
-exo_wrap_table_get_type (void)
-{
-  static GType type = G_TYPE_INVALID;
-
-  if (G_UNLIKELY (type == G_TYPE_INVALID))
-    {
-      type = _exo_g_type_register_simple (GTK_TYPE_CONTAINER,
-                                          "ExoWrapTable",
-                                          sizeof (ExoWrapTableClass),
-                                          exo_wrap_table_class_init,
-                                          sizeof (ExoWrapTable),
-                                          exo_wrap_table_init);
-    }
-
-  return type;
-}
+G_DEFINE_TYPE (ExoWrapTable, exo_wrap_table, GTK_TYPE_CONTAINER)
 
 
 
@@ -128,9 +120,6 @@ exo_wrap_table_class_init (ExoWrapTableClass *klass)
   /* add our private data to the class */
   g_type_class_add_private (klass, sizeof (ExoWrapTablePrivate));
 
-  /* determine our parent type class */
-  exo_wrap_table_parent_class = g_type_class_peek_parent (klass);
-
   gobject_class = G_OBJECT_CLASS (klass);
   gobject_class->get_property = exo_wrap_table_get_property;
   gobject_class->set_property = exo_wrap_table_set_property;
@@ -577,7 +566,7 @@ exo_wrap_table_get_num_fitting (gint available,
  *
  * Allocates a new #ExoWrapTable.
  *
- * Return value: the newly allocated #ExoWrapTable.
+ * Returns: the newly allocated #ExoWrapTable.
  *
  * Since: 0.3.1
  **/
@@ -598,8 +587,7 @@ exo_wrap_table_new (gboolean homogeneous)
  * Returns the amount of space between consecutive
  * columns in @table.
  *
- * Return value: the amount of space between
- *               consecutive columns.
+ * Returns: the amount of space between consecutive columns.
  *
  * Since: 0.3.1
  **/
@@ -627,7 +615,7 @@ exo_wrap_table_set_col_spacing (ExoWrapTable *table,
                                 guint         col_spacing)
 {
   g_return_if_fail (EXO_IS_WRAP_TABLE (table));
-  
+
   if (G_LIKELY (table->priv->col_spacing != col_spacing))
     {
       table->priv->col_spacing = col_spacing;
@@ -645,8 +633,7 @@ exo_wrap_table_set_col_spacing (ExoWrapTable *table,
  * Returns the amount of space between consecutive
  * rows in @table.
  *
- * Return value: the amount of space between
- *               consecutive rows in @table.
+ * Returns: the amount of space between consecutive rows in @table.
  *
  * Since: 0.3.1
  **/
@@ -692,8 +679,7 @@ exo_wrap_table_set_row_spacing (ExoWrapTable *table,
  * Returns whether the table cells are all constrained
  * to the same width and height.
  *
- * Return value: %TRUE if the cells are all constrained
- *               to the same size.
+ * Returns: %TRUE if the cells are all constrained to the same size.
  *
  * Since: 0.3.1
  **/
